@@ -1,5 +1,5 @@
-#ifndef _HUNSPELL_VISIBILITY_H_
-#define _HUNSPELL_VISIBILITY_H_
+#ifndef HUNSPELL_VISIBILITY_H_
+#define HUNSPELL_VISIBILITY_H_
 
 #if defined(HUNSPELL_STATIC)
 #  define LIBHUNSPELL_DLL_EXPORTED
