@@ -9,10 +9,10 @@
 
 QtAPI=${QtAPI:-"-cocoa"}
 QtVersion=${QtVersion:-"4.6.3"}
-QtSourceVersion="qt-everywhere-opensource-src-${QtVersion}"
+QtSourceVersion=${QtSourceVersion:-"qt-everywhere-opensource-src-${QtVersion}"}
 QtBuildSubDir="qt-${QtVersion}-build${QtAPI}"
 QtConfigureOptions=${QtConfigureOptions:-"-release"}
-
+QtSkipComponents=${QtSkipComponents:-"qtconnectivity qtscript qtquickcontrols qtmultimedia qtvirtualkeyboard qtwayland qtwebengine"}
 LibMagicVersion=${LibMagicVersion:-"5.19"}
 LibMagicSource="file-${LibMagicVersion}"
 LibMagicLibrary="libmagic.1.dylib"
@@ -79,9 +79,9 @@ case "${QtVersion}:${QtAPI}" in
 	QtConfigureOptions="${QtConfigureOptions} -no-strip"
 	QtConfigureOptions="${QtConfigureOptions} -no-kms -no-pkg-config"
 	QtConfigureOptions="${QtConfigureOptions} -nomake examples -nomake tools"
-	QtConfigureOptions="${QtConfigureOptions} -skip qtquick1 -skip qtwebkit -skip qtconnectivity -skip qtscript"
-	QtConfigureOptions="${QtConfigureOptions} -skip qtquickcontrols"
-#	QtConfigureOptions="${QtConfigureOptions} -skip qtdeclarative"
+	for component in ${QtSkipComponents} ; do
+		QtConfigureOptions="${QtConfigureOptions} -skip ${component}"
+	done
 	QtMajorVersion=qt5
 	;;
 *)
@@ -357,15 +357,19 @@ LyxAppPrefix="${LyxAppDir}.app"
 # don't change order here...
 case "${QtVersion}" in
 5.0.*|5.1.*)
-	QtLibraries="QtSvg QtXml QtPrintSupport QtWidgets QtGui QtNetwork QtConcurrent QtCore"
+	QtLibraries=${QtLibraries:-"QtSvg QtXml QtPrintSupport QtWidgets QtGui QtNetwork QtConcurrent QtCore"}
+	QtFrameworkVersion="5"
+	;;
+5.12.*)
+	QtLibraries=${QtLibraries:-"QtDbus QtSvg QtXml QtPrintSupport QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"}
 	QtFrameworkVersion="5"
 	;;
 5*)
-	QtLibraries="QtSvg QtXml QtPrintSupport QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"
+	QtLibraries=${QtLibraries:-"QtSvg QtXml QtPrintSupport QtMacExtras QtWidgets QtGui QtNetwork QtConcurrent QtCore"}
 	QtFrameworkVersion="5"
 	;;
 *)
-	QtLibraries="QtSvg QtXml QtGui QtNetwork QtCore"
+	QtLibraries=${QtLibraries:-"QtSvg QtXml QtGui QtNetwork QtCore"}
 	QtFrameworkVersion="4"
 	;;
 esac
@@ -442,7 +446,7 @@ if [ -d "${LibMagicSourceDir}" -a ! -f "${LibMagicInstallHdr}" ]; then
 	# we have a private libmagic (file(1)) source tree at hand...
 	# so let's build and install it
 	if [ -z "${LibMagicVersion}" ]; then
-		LibMagicVersion=$(grep AC_INIT "${LibMagicSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
+		LibMagicVersion=$(grep AC_INIT "${LibMagicSourceDir}"/configure.ac | cut -d, -f2|tr -d " []()")
 	fi
 
 	LibMagicName="LibMagic"
@@ -503,7 +507,7 @@ if [ -d "${HunSpellSourceDir}" -a ! -f "${HunSpellInstallHdr}" ]; then
 	# we have a private HunSpell source tree at hand...
 	# so let's build and install it
 	if [ -z "${HunSpellVersion}" ]; then
-		HunSpellVersion=$(grep AC_INIT "${HunSpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
+		HunSpellVersion=$(grep AC_INIT "${HunSpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " []()")
 	fi
 
 	HunSpellName="Hunspell"
@@ -565,7 +569,7 @@ if [ -d "${ASpellSourceDir}" -a ! -f "${ASpellInstallHdr}" -a "yes" = "${aspell_
 	# we have a private ASpell source tree at hand...
 	# so let's build and install it
 	if [ -z "${ASpellVersion}" ]; then
-		ASpellVersion=$(grep AC_INIT "${ASpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " ()")
+		ASpellVersion=$(grep AC_INIT "${ASpellSourceDir}"/configure.ac | cut -d, -f2|tr -d " []()")
 	fi
 
 	ASpellName="Aspell"
@@ -1026,7 +1030,7 @@ make_dmg() {
 	ln -s /Applications/ "${VOLUME}"/Applications
 	test -d "${DocumentationDir}" && ditto --hfsCompression "${DocumentationDir}" "${VOLUME}"
 	set_bundle_display_options "${VOLUME}" ${BG_W} ${BG_H}
-	${XCODE_DEVELOPER}/Tools/SetFile -a C "${VOLUME}"
+	PATH="${XCODE_DEVELOPER}/Tools:$PATH" SetFile -a C "${VOLUME}"
 	mv "${VOLUME}/Pictures" "${VOLUME}/.Pictures"
 
 	# Unmount the disk image
