@@ -8,25 +8,26 @@
 
 # Full author contact details are available in file CREDITS
 
-# This script is intended to include a BibTeX-generated biblography 
+# This script is intended to include a BibTeX-generated biblography
 # in a LaTeX file, as publishers often want. It can be run manually
 # on an exported LaTeX file, though it needs to be compiled first,
 # so the bbl file will exist.
 #
 # It should also be possible to create a LyX converter to run this
-# automatically. To set it up, create a format "ltxbbl"; make sure to 
-# check it as a document format. Then create a LaTeX-->ltxbbl converter, 
+# automatically. To set it up, create a format "ltxbbl"; make sure to
+# check it as a document format. Then create a LaTeX-->ltxbbl converter,
 # with the command:
 #   python -tt $$s/scripts/include_bib.py $$i $$o
 # and give it the flags:
 #   needaux,nice
 # You'll then have it in the export menu.
-# 
+#
 # We do not activate this converter by default, because there are problems
 # when one tries to use multiple bibliographies.
 #
 # Please report any problems on the devel list.
 
+from __future__ import print_function
 import sys, os
 
 class secbib:
@@ -42,7 +43,7 @@ class BibError(Exception):
     return self.msg
 
 
-def InsertBib(fil, out):   
+def InsertBib(fil, out):
   ''' Inserts the contents of the .bbl file instead of the bibliography in a new .tex file '''
 
   texlist = open(fil, 'r').readlines()
@@ -50,7 +51,7 @@ def InsertBib(fil, out):
   # multiple bibliographies
   biblist = []
   stylist = []
-  
+
   for i, line in enumerate(texlist):
     if "\\bibliographystyle" in line:
       stylist.append(i)
@@ -58,7 +59,7 @@ def InsertBib(fil, out):
       biblist.append(i)
     elif "\\begin{btSect}" in line:
       raise BibError("Cannot export sectioned bibliographies")
-  
+
   if len(biblist) > 1:
     raise BibError("Cannot export multiple bibliographies.")
   if not biblist:
@@ -70,21 +71,21 @@ def InsertBib(fil, out):
   bbllist = open(bblfile, 'r').readlines()
   newlist += bbllist
   newlist += texlist[bibpos + 1:]
-    
+
   outfile = open(out, 'w')
   outfile.write("".join(newlist))
   outfile.close()
   return out
-    
+
 
 def usage():
-  print r'''
+  print (r'''
 Usage: python include_bib.py file.tex [outfile.tex]
   Includes the contents of file.bbl, which must exist in the
   same directory as file.tex, in place of the \bibliography
   command, and creates the new file outfile.tex. If no name
   for that file is given, we create: file-bbl.tex.
-'''  
+''')
 
 if __name__ == "__main__":
   args = len(sys.argv)
@@ -95,7 +96,7 @@ if __name__ == "__main__":
   # we might should make sure this is a tex file....
   infile = sys.argv[1]
   if infile[-4:] != ".tex":
-    print "Error: " + infile + " is not a TeX file"
+    print ("Error: " + infile + " is not a TeX file")
     usage()
     sys.exit(1)
 
@@ -105,4 +106,4 @@ if __name__ == "__main__":
     outfile = infile[:-4] + "-bbl.tex"
 
   newfile = InsertBib(infile, outfile)
-  print "Wrote " + outfile
+  print ("Wrote " + outfile)
