@@ -44,7 +44,7 @@ def writeString(outfile, infile, basefile, lineno, string):
 
 def ui_l10n(input_files, output, base):
     '''Generate pot file from lib/ui/*'''
-    output = io.open(output, 'w', encoding='utf_8')
+    output = io.open(output, 'w', encoding='utf_8', newline='\n')
     Submenu = re.compile(r'^[^#]*Submenu\s+"([^"]*)"', re.IGNORECASE)
     Popupmenu = re.compile(r'^[^#]*PopupMenu\s+"[^"]+"\s+"([^"]*)"', re.IGNORECASE)
     IconPalette = re.compile(r'^[^#]*IconPalette\s+"[^"]+"\s+"([^"]*)"', re.IGNORECASE)
@@ -78,23 +78,24 @@ def ui_l10n(input_files, output, base):
 
 
 def layouts_l10n(input_files, output, base, layouttranslations):
-    '''Generate pot file from lib/layouts/*.{layout,inc,module}'''
+    '''Generate pot file from lib/layouts/*.{layout,inc,module} and lib/citeengines/*.citeengine'''
     ClassDescription = re.compile(r'^\s*#\s*\\Declare(LaTeX|DocBook)Class.*\{(.*)\}$', re.IGNORECASE)
     ClassCategory = re.compile(r'^\s*#\s*\\DeclareCategory\{(.*)\}$', re.IGNORECASE)
     Style = re.compile(r'^\s*Style\s+(.*\S)\s*$', re.IGNORECASE)
     # match LabelString, EndLabelString, LabelStringAppendix and maybe others but no comments
     LabelString = re.compile(r'^[^#]*LabelString\S*\s+(.*\S)\s*$', re.IGNORECASE)
     MenuString = re.compile(r'^[^#]*MenuString\S*\s+(.*\S)\s*$', re.IGNORECASE)
-    OutlinerName = re.compile(r'^[^#]*OutlinerName\s+(\S+|\"[^\"]*\")\s+(\S+|\"[^\"]*\")\s*$', re.IGNORECASE)
+    OutlinerName = re.compile(r'^[^#]*OutlinerName\s+(\S+|\"[^\"]*\")\s+\"([^\"]*)\"', re.IGNORECASE)
     Tooltip = re.compile(r'^\s*Tooltip\S*\s+(.*\S)\s*$', re.IGNORECASE)
     GuiName = re.compile(r'^\s*GuiName\s+(.*\S)\s*$', re.IGNORECASE)
     ListName = re.compile(r'^\s*ListName\s+(.*\S)\s*$', re.IGNORECASE)
     CategoryName = re.compile(r'^\s*Category\s+(.*\S)\s*$', re.IGNORECASE)
     NameRE = re.compile(r'^\s*#\s*\\DeclareLyXModule.*{(.*)}$', re.IGNORECASE)
+    CiteNameRE = re.compile(r'^\s*#\s*\\DeclareLyXCiteEngine.*\{(.*)\}$', re.IGNORECASE)
     InsetLayout = re.compile(r'^InsetLayout\s+\"?(.*)\"?\s*$', re.IGNORECASE)
     FlexCheck = re.compile(r'^Flex:(.*)', re.IGNORECASE)
     CaptionCheck = re.compile(r'^Caption:(.*)', re.IGNORECASE)
-    DescBegin = re.compile(r'^\s*#DescriptionBegin\s*$', re.IGNORECASE)
+    DescBegin = re.compile(r'^\s*#\s*DescriptionBegin\s*$', re.IGNORECASE)
     DescEnd = re.compile(r'^\s*#\s*DescriptionEnd\s*$', re.IGNORECASE)
     Category = re.compile(r'^\s*#\s*Category:\s+(.*\S)\s*$', re.IGNORECASE)
     I18nPreamble = re.compile(r'^\s*((Lang)|(Babel))Preamble\s*$', re.IGNORECASE)
@@ -102,7 +103,8 @@ def layouts_l10n(input_files, output, base, layouttranslations):
     I18nString = re.compile(r'_\(([^\)]+)\)')
     CounterFormat = re.compile(r'^\s*PrettyFormat\s+"?(.*)"?\s*$', re.IGNORECASE)
     CiteFormat = re.compile(r'^\s*CiteFormat', re.IGNORECASE)
-    KeyVal = re.compile(r'^\s*_\w+\s+(.*\S)\s*$')
+    # Note: preceding and trailing space in the val below matters
+    KeyVal = re.compile(r'^\s*_\w+\s(.*\S)*$')
     Float = re.compile(r'^\s*Float\s*$', re.IGNORECASE)
     UsesFloatPkg = re.compile(r'^\s*UsesFloatPkg\s+(.*\S)\s*$', re.IGNORECASE)
     IsPredefined = re.compile(r'^\s*IsPredefined\s+(.*\S)\s*$', re.IGNORECASE)
@@ -166,7 +168,10 @@ def layouts_l10n(input_files, output, base, layouttranslations):
         if 'wa' in languages:
             languages.remove('wa')
 
-    out = io.open(output, 'w', encoding='utf_8')
+    if layouttranslations:
+        out = io.open(output, 'w', encoding='utf_8')
+    else:
+        out = io.open(output, 'w', encoding='utf_8', newline='\n')
     for src in input_files:
         readingDescription = False
         readingI18nPreamble = False
@@ -226,6 +231,12 @@ def layouts_l10n(input_files, output, base, layouttranslations):
                 readingI18nPreamble = True
                 continue
             res = NameRE.search(line)
+            if res != None:
+                string = res.group(1)
+                if not layouttranslations:
+                    writeString(out, src, base, lineno + 1, string)
+                continue
+            res = CiteNameRE.search(line)
             if res != None:
                 string = res.group(1)
                 if not layouttranslations:
@@ -433,7 +444,7 @@ def layouts_l10n(input_files, output, base, layouttranslations):
 
 def qt4_l10n(input_files, output, base):
     '''Generate pot file from src/frontends/qt4/ui/*.ui'''
-    output = io.open(output, 'w', encoding='utf_8')
+    output = io.open(output, 'w', encoding='utf_8', newline='\n')
     pat = re.compile(r'\s*<string>(.*)</string>')
     prop = re.compile(r'\s*<property.*name.*=.*shortcut')
     for src in input_files:
@@ -462,7 +473,7 @@ def qt4_l10n(input_files, output, base):
 
 def languages_l10n(input_files, output, base):
     '''Generate pot file from lib/languages'''
-    out = io.open(output, 'w', encoding='utf_8')
+    out = io.open(output, 'w', encoding='utf_8', newline='\n')
     GuiName = re.compile(r'^[^#]*GuiName\s+(.*)', re.IGNORECASE)
 
     for src in input_files:
@@ -482,7 +493,7 @@ def languages_l10n(input_files, output, base):
 
 def latexfonts_l10n(input_files, output, base):
     '''Generate pot file from lib/latexfonts'''
-    out = io.open(output, 'w', encoding='utf_8')
+    out = io.open(output, 'w', encoding='utf_8', newline='\n')
     GuiName = re.compile(r'^[^#]*GuiName\s+(.*)', re.IGNORECASE)
 
     for src in input_files:
@@ -501,8 +512,8 @@ def latexfonts_l10n(input_files, output, base):
 
 
 def external_l10n(input_files, output, base):
-    '''Generate pot file from lib/external_templates'''
-    output = io.open(output, 'w', encoding='utf_8')
+    '''Generate pot file from lib/xtemplates'''
+    output = io.open(output, 'w', encoding='utf_8', newline='\n')
     Template = re.compile(r'^Template\s+(.*)', re.IGNORECASE)
     GuiName = re.compile(r'\s*GuiName\s+(.*)', re.IGNORECASE)
     HelpTextStart = re.compile(r'\s*HelpText\s', re.IGNORECASE)
@@ -529,6 +540,8 @@ def external_l10n(input_files, output, base):
                 elif HelpTextSection.match(line):
                     (help_string,) = HelpTextSection.match(line).groups()
                     help_string = help_string.replace('"', '')
+                    help_string =  help_string.replace('\\', '_backsl_')
+                    help_string =  help_string.replace('_backsl_', '\\\\')
                     if help_string != "" and prev_help_string == '':
                         print(u'#: %s:%d\nmsgid ""\n"%s\\n"' % \
                             (relativePath(src, base), lineno+1, help_string), file=output)
@@ -536,6 +549,10 @@ def external_l10n(input_files, output, base):
                     elif help_string != "":
                         print(u'"%s\\n"' % help_string, file=output)
                     prev_help_string = help_string
+                else:
+                    # Empty line
+                    print(u'"\\n"', file=output)
+                    prev_help_string = 'xxxx'
             elif HelpTextStart.match(line):
                 inHelp = True
                 prev_help_string = ''
@@ -551,7 +568,7 @@ def external_l10n(input_files, output, base):
 
 def formats_l10n(input_files, output, base):
     '''Generate pot file from configure.py'''
-    output = io.open(output, 'w', encoding='utf_8')
+    output = io.open(output, 'w', encoding='utf_8', newline='\n')
     GuiName = re.compile(r'.*\\Format\s+\S+\s+\S+\s+"([^"]*)"\s+(\S*)\s+.*', re.IGNORECASE)
     GuiName2 = re.compile(r'.*\\Format\s+\S+\s+\S+\s+([^"]\S+)\s+(\S*)\s+.*', re.IGNORECASE)
     input = io.open(input_files[0], encoding='utf_8')
@@ -581,17 +598,19 @@ def formats_l10n(input_files, output, base):
 
 def encodings_l10n(input_files, output, base):
     '''Generate pot file from lib/encodings'''
-    output = io.open(output, 'w', encoding='utf_8')
+    output = io.open(output, 'w', encoding='utf_8', newline='\n')
     # assuming only one encodings file
     #                 Encoding utf8      utf8    "Unicode (utf8)" UTF-8    variable inputenc
-    reg = re.compile('Encoding [\w-]+\s+[\w-]+\s+"([\w \-\(\)]+)"\s+[\w-]+\s+(fixed|variable|variableunsafe)\s+\w+.*')
+    reg = re.compile('Encoding [\w-]+\s+[\w-]+\s+"([\w \-\(\)^"]*)"\s+["\w-]+\s+(fixed|variable|variableunsafe)\s+\w+.*')
     input = io.open(input_files[0], encoding='utf_8')
     for lineno, line in enumerate(input.readlines()):
         if not line.startswith('Encoding'):
             continue
         if reg.match(line):
-            print(u'#: %s:%d\nmsgid "%s"\nmsgstr ""\n' % \
-                (relativePath(input_files[0], base), lineno+1, reg.match(line).groups()[0]), file=output)
+            guiname = reg.match(line).groups()[0]
+            if guiname != "":
+                print(u'#: %s:%d\nmsgid "%s"\nmsgstr ""\n' % \
+                    (relativePath(input_files[0], base), lineno+1, guiname), file=output)
         else:
             print("Error: Unable to handle line:")
             print(line)
@@ -620,7 +639,7 @@ where
         languages: file lib/languages
         latexfonts: file lib/latexfonts
         encodings: file lib/encodings
-        external: external templates file
+        external: external templates files
         formats: formats predefined in lib/configure.py
 '''
 
