@@ -136,7 +136,9 @@ public:
 	/// NOTE: This does not call makeDocumentClass() to update the local
 	/// DocumentClass. That needs to be done manually.
 	/// \param classname: the name of the layout file
-	bool setBaseClass(std::string const & classname);
+	/// \param path: non-empty only for local layout files
+	bool setBaseClass(std::string const & classname,
+	                  std::string const & path = std::string());
 	/// Adds the module information to the baseClass information to
 	/// create our local DocumentClass.
 	/// NOTE: This should NEVER be called externally unless one immediately goes
@@ -551,6 +553,10 @@ public:
 	bool setLanguage(std::string const & lang);
 	///
 	void invalidateConverterCache() const;
+	/// Copies over some of the settings from \param bp,
+	/// namely the ones need by Advanced F&R. We don't want
+	/// to copy them all, e.g., not the default master.
+	void copyForAdvFR(BufferParams const & bp);
 
 private:
 	///
@@ -614,7 +620,6 @@ private:
 		static void destroy(Impl *);
 	};
 	support::copied_ptr<Impl, MemoryTraits> pimpl_;
-
 };
 
 } // namespace lyx
