@@ -1504,6 +1504,10 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 
 	case LFUN_NOTE_NEXT:
 		gotoInset(this, NOTE_CODE, false);
+		// FIXME: if SinglePar is changed to act on the inner
+		// paragraph, this will not be OK anymore. The update is
+		// useful for auto-open collapsible insets.
+		dr.screenUpdate(Update::SinglePar | Update::FitCursor);
 		break;
 
 	case LFUN_REFERENCE_NEXT: {
@@ -1511,6 +1515,10 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 		tmp.push_back(LABEL_CODE);
 		tmp.push_back(REF_CODE);
 		gotoInset(this, tmp, true);
+		// FIXME: if SinglePar is changed to act on the inner
+		// paragraph, this will not be OK anymore. The update is
+		// useful for auto-open collapsible insets.
+		dr.screenUpdate(Update::SinglePar | Update::FitCursor);
 		break;
 	}
 
@@ -2746,7 +2754,7 @@ bool BufferView::singleParUpdate()
 	Text & buftext = buffer_.text();
 	pit_type const bottom_pit = d->cursor_.bottom().pit();
 	TextMetrics & tm = textMetrics(&buftext);
-	int old_height = tm.parMetrics(bottom_pit).height();
+	Dimension const old_dim = tm.parMetrics(bottom_pit).dim();
 
 	// make sure inline completion pointer is ok
 	if (d->inlineCompletionPos_.fixIfBroken())
@@ -2757,11 +2765,16 @@ bool BufferView::singleParUpdate()
 	// (if this paragraph contains insets etc., rebreaking will
 	// recursively descend)
 	tm.redoParagraph(bottom_pit);
-	ParagraphMetrics const & pm = tm.parMetrics(bottom_pit);
-	if (pm.height() != old_height)
+	ParagraphMetrics & pm = tm.par_metrics_[bottom_pit];
+	if (pm.height() != old_dim.height()) {
 		// Paragraph height has changed so we cannot proceed to
 		// the singlePar optimisation.
 		return false;
+	}
+	// Since position() points to the baseline of the first row, we
+	// may have to update it. See ticket #11601 for an example where
+	// the height does not change but the ascent does.
+	pm.setPosition(pm.position() - old_dim.ascent() + pm.ascent());
 
 	tm.updatePosCache(bottom_pit);
 
@@ -3047,11 +3060,16 @@ void BufferView::caretPosAndHeight(Point & p, int & h) const
 }
 
 
-bool BufferView::cursorInView(Point const & p, int h) const
+bool BufferView::caretInView() const
 {
-	Cursor const & cur = cursor();
+	if (!paragraphVisible(cursor()))
+		return false;
+	Point p;
+	int h;
+	caretPosAndHeight(p, h);
+
 	// does the cursor touch the screen ?
-	if (p.y_ + h < 0 || p.y_ >= workHeight() || !paragraphVisible(cur))
+	if (p.y_ + h < 0 || p.y_ >= workHeight())
 		return false;
 	return true;
 }
