@@ -21,6 +21,7 @@
 
 #include "insets/InsetText.h"
 
+#include "support/docstream.h"
 #include "support/lassert.h"
 #include "support/lyxalgo.h"
 #include "support/qstring_helpers.h"
@@ -63,10 +64,10 @@ public:
 		: from(from_), to(to_)
 	{}
 
-	DocRange(Buffer const * buf)
+	DocRange(Buffer const * buf) :
+		from(doc_iterator_begin(buf)),
+		to(doc_iterator_end(buf))
 	{
-		from = doc_iterator_begin(buf);
-		to = doc_iterator_end(buf);
 		to.backwardPos();
 	}
 
@@ -391,7 +392,7 @@ void Compare::run()
 		dest_buffer->params().authors().record(*it);
 
 	// We will need this later
-	DocumentClassConstPtr const olddc = 
+	DocumentClassConstPtr const olddc =
 		dest_buffer->params().documentClassPtr();
 	// We do not want to share the DocumentClass with the other Buffer.
 	// See bug #10295.
