@@ -12,6 +12,8 @@
 #ifndef ERRORLIST_H
 #define ERRORLIST_H
 
+#include "TexRow.h"
+
 #include "support/docstring.h"
 #include "support/types.h"
 
@@ -25,15 +27,19 @@ class Buffer;
 /// A class to hold an error item
 class ErrorItem {
 public:
+	typedef TexRow::TextEntry TextEntry;
 	docstring error;
 	docstring description;
-	int par_id;
-	pos_type pos_start;
-	pos_type pos_end;
+	// To generalise into RowEntries
+	TextEntry start;
+	TextEntry end;
 	Buffer const * buffer;
+	// With a start position and an end position
 	ErrorItem(docstring const & error, docstring const & description,
-		  int parid, pos_type posstart, pos_type posend,
-		  Buffer const * buf = 0);
+	          TextEntry start, TextEntry end, Buffer const * buf = 0);
+	// Error outside the document body
+	ErrorItem(docstring const & error, docstring const & description,
+	          Buffer const * buf = 0);
 	ErrorItem();
 };
 
