@@ -105,13 +105,6 @@ public:
 	///
 	void decreasePosAfterPos(pos_type pos);
 
-	/// Returns the height of the highest font in range
-	FontSize highestInRange(
-		pos_type startpos,
-		pos_type endpos,
-		FontSize def_size
-		) const;
-
 	///
 	void validate(LaTeXFeatures & features) const;
 
