@@ -41,11 +41,6 @@ LyXVC::LyXVC()
 }
 
 
-// for the sake of boost::scoped_ptr
-LyXVC::~LyXVC()
-{}
-
-
 docstring LyXVC::vcstatus() const
 {
 	if (!vcs)
@@ -267,7 +262,7 @@ string LyXVC::checkOut()
 	if (!vcs)
 		return string();
 	//RCS allows checkOut only in ReadOnly mode
-	if (vcs->toggleReadOnlyEnabled() && !owner_->isReadonly())
+	if (vcs->toggleReadOnlyEnabled() && !owner_->hasReadonlyFlag())
 		return string();
 
 	LYXERR(Debug::LYXVC, "LyXVC: checkOut");
@@ -340,7 +335,7 @@ string LyXVC::toggleReadOnly()
 	}
 	case VCS::NOLOCKING:
 		Buffer * b = vcs->owner();
-		bool const newstate = !b->isReadonly();
+		bool const newstate = !b->hasReadonlyFlag();
 		string result = "LyXVC: toggle to ";
 		result += (newstate ? "readonly" : "readwrite");
 		LYXERR(Debug::LYXVC, result);
@@ -452,8 +447,8 @@ bool LyXVC::repoUpdateEnabled() const
 {
 	return vcs && vcs->repoUpdateEnabled();
 }
-	
-	
+
+
 bool LyXVC::prepareFileRevision(string const & rev, std::string & f)
 {
 	return vcs && vcs->prepareFileRevision(rev, f);
