@@ -12,9 +12,8 @@
 #ifndef LYX_VC_H
 #define LYX_VC_H
 
-#include <boost/scoped_ptr.hpp>
-
 #include "support/docstring.h"
+#include "support/unique_ptr.h"
 
 #include <string>
 
@@ -50,8 +49,6 @@ public:
 	};
 	///
 	LyXVC();
-	///
-	~LyXVC();
 	/// Status of the underlying VCS
 	docstring vcstatus() const;
 	/// Is \p fn under version control?
@@ -194,7 +191,7 @@ private:
 	Buffer * owner_;
 
 	///
-	boost::scoped_ptr<VCS> vcs;
+	unique_ptr<VCS> vcs;
 };
 
 
