@@ -280,10 +280,14 @@ int Trans::load(Lexer & lex)
 				    && it->second[1] == accent_2)
 					break;
 			}
+
+			// could not find accent2 on a key -- this should not happen.
+			if (it == end)
+				return -1;
+
 			docstring allowed;
 			if (!lex.next())
 				return -1;
-
 			allowed = lex.getDocString();
 			LYXERR(Debug::KBMAP, "allowed: " << to_utf8(allowed));
 
