@@ -183,7 +183,7 @@ docstring const VSpace::asGUIName() const
 }
 
 
-string VSpace::asHTMLLength() const 
+string VSpace::asHTMLLength() const
 {
 	string result;
 	switch (kind_) {
@@ -212,13 +212,13 @@ int VSpace::inPixels(BufferView const & bv) const
 	case DEFSKIP:
 		return bv.buffer().params().getDefSkip().inPixels(bv);
 
-	// This is how the skips are normally defined by LateX.
+	// This is how the skips are normally defined by LaTeX.
 	// But there should be some way to change this per document.
 	case SMALLSKIP:
-		return default_height / 4;
+		return int(default_height / 4);
 
 	case MEDSKIP:
-		return default_height / 2;
+		return int(default_height / 2);
 
 	case BIGSKIP:
 		return default_height;
@@ -228,7 +228,7 @@ int VSpace::inPixels(BufferView const & bv) const
 		return 3 * default_height;
 
 	case LENGTH:
-		return len_.len().inPixels(bv.workWidth());
+		return bv.inPixels(len_.len());
 
 	default:
 		LATTEST(false);
