@@ -19,8 +19,7 @@
 #include "support/lstrings.h"
 #include "support/Messages.h"
 #include "support/unicode.h"
-
-#include <boost/scoped_ptr.hpp>
+#include "support/unique_ptr.h"
 
 // getpid(), getppid()
 #ifdef HAVE_SYS_TYPES_H
@@ -61,13 +60,15 @@
 #include <map>
 #include <iostream>
 
+
 using namespace std;
 using namespace lyx::support;
 
-using ::boost::scoped_ptr;
-
 namespace lyx {
 
+// Dummy verbose support
+bool verbose = false;
+
 // Dummy LyXRC support
 struct LyXRC {
 	string icon_set;
@@ -506,9 +507,11 @@ int g(vector<docstring> const & arg)
 		     << endl;
 		return -1;
 	}
-	singleCommand = "LYXCMD:server-goto-file-row "
-		+ arg[0] + ' '
-		+ arg[1];
+	singleCommand = "LYXCMD:command-sequence "
+		"server-goto-file-row "
+			+ arg[0] + ' '
+			+ arg[1] + "; " +
+		"lyx-activate";
 	return 2;
 }
 
@@ -618,7 +621,7 @@ int LyXClientApp::run()
 		return EXIT_FAILURE;
 	}
 
-	scoped_ptr<LyXDataSocket> server;
+	unique_ptr<LyXDataSocket> server;
 
 	if (!cmdline::serverAddress.empty()) {
 		server.reset(new LyXDataSocket(FileName(to_utf8(cmdline::serverAddress))));
