@@ -1027,6 +1027,10 @@ GuiApplication::GuiApplication(int & argc, char ** argv)
 	QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
 
+#if QT_VERSION >= 0x050700
+	setDesktopFileName(lyx_package);
+#endif
+
 	qsrand(QDateTime::currentDateTime().toTime_t());
 
 	// Install translator for GUI elements.
