@@ -29,6 +29,7 @@
 #include <QPixmap>
 #include <QCheckBox>
 #include <QListWidgetItem>
+#include <QScrollBar>
 
 #include <map>
 #include <string>
@@ -176,7 +177,7 @@ string getDelimiterName(QListWidgetItem const * lwi)
 }
 
 
-} // anon namespace
+} // namespace
 
 
 GuiDelimiter::GuiDelimiter(GuiView & lv)
@@ -201,6 +202,9 @@ GuiDelimiter::GuiDelimiter(GuiView & lv)
 	QFontMetrics fm(frontend::getFont(lyxfont));
 	QSize item_size(fm.maxWidth(), fm.height() + 8);
 
+	leftLW->setMinimumWidth(5 * item_size.width());
+	rightLW->setMinimumWidth(5 * item_size.width());
+
 	typedef map<char_type, QListWidgetItem *> ListItems;
 	ListItems list_items;
 	// The last element is the empty one.
@@ -248,6 +252,8 @@ GuiDelimiter::GuiDelimiter(GuiView & lv)
 		sizeCO->addItem(qt_(biggui[i]));
 
 	on_leftLW_currentRowChanged(0);
+	// synchronise the scroll bars
+	on_matchCB_stateChanged(matchCB->checkState());
 	bc().setPolicy(ButtonPolicy::IgnorantPolicy);
 }
 
@@ -385,9 +391,23 @@ void GuiDelimiter::on_rightLW_currentRowChanged(int item)
 
 void GuiDelimiter::on_matchCB_stateChanged(int state)
 {
-	if (state == Qt::Checked)
+	// Synchronise the vertical scroll bars when checked
+	QScrollBar * ls = leftLW->verticalScrollBar();
+	QScrollBar * rs = rightLW->verticalScrollBar();
+
+	if (state == Qt::Checked) {
 		on_leftLW_currentRowChanged(leftLW->currentRow());
 
+		connect(ls, SIGNAL(valueChanged(int)), rs, SLOT(setValue(int)),
+		        Qt::UniqueConnection);
+		connect(rs, SIGNAL(valueChanged(int)), ls, SLOT(setValue(int)),
+		        Qt::UniqueConnection);
+		rs->setValue(ls->value());
+	} else {
+		ls->disconnect(rs);
+		rs->disconnect(ls);
+	}
+
 	updateTeXCode(sizeCO->currentIndex());
 }
 
