@@ -25,12 +25,15 @@ namespace lyx {
 namespace frontend {
 
 GuiDialog::GuiDialog(GuiView & lv, QString const & name, QString const & title)
-	: QDialog(&lv), Dialog(lv, name, "LyX: " + title), updating_(false), 
+	: QDialog(&lv), Dialog(lv, name, "LyX: " + title), updating_(false),
 	  is_closing_(false)
 {
+	connect(&lv, SIGNAL(bufferViewChanged()),
+	        this, SLOT(onBufferViewChanged()));
+
 	// remove question marks from Windows dialogs
 	setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
-} 
+}
 
 
 void GuiDialog::closeEvent(QCloseEvent * ev)
