@@ -15,12 +15,12 @@
 #include "GuiInclude.h"
 
 #include "Buffer.h"
+#include "BufferList.h"
 #include "BufferParams.h"
 #include "FuncRequest.h"
 #include "LyXRC.h"
 
 #include "qt_helpers.h"
-#include "LyXRC.h"
 
 #include "support/gettext.h"
 #include "support/lstrings.h"
@@ -28,12 +28,15 @@
 #include "support/FileName.h"
 #include "support/filetools.h"
 
+#include "frontends/alert.h"
+
 #include "insets/InsetListingsParams.h"
 #include "insets/InsetInclude.h"
 
-#include <QPushButton>
 #include <QCheckBox>
+#include <QFile>
 #include <QLineEdit>
+#include <QPushButton>
 
 #include <utility>
 
@@ -265,6 +268,68 @@ void GuiInclude::applyView()
 		else
 			params_.setCmdName("verbatiminput");
 	}
+
+	// Do we need to create a LyX file?
+	if (item == 0 || item == 1) {
+		QString fname = filenameED->text();
+		string const mypath = buffer().absFileName();
+		string const bpath = buffer().filePath();
+		QString absfname = makeAbsPath(fname, toqstr(bpath));
+		if (!QFile::exists(absfname)) {
+			dispatch(FuncRequest(LFUN_BUFFER_NEW, fromqstr(absfname)));
+			dispatch(FuncRequest(LFUN_BUFFER_WRITE));
+			dispatch(FuncRequest(LFUN_BUFFER_SWITCH, mypath));
+		}
+	}
+}
+
+
+void GuiInclude::edit()
+{
+	if (!isValid())
+		return;
+	if (bc().policy().buttonStatus(ButtonPolicy::OKAY)) {
+		slotOK();
+		applyView();
+	} else
+		hideView();
+	QString const fname = filenameED->text();
+	string const bpath = buffer().filePath();
+	string const absfname = support::makeAbsPath(fromqstr(fname), bpath).absFileName();
+	// The button is enabled only if the document is already open.
+	// If something goes wrong and it is not, we'll get an error
+	// message from the dispatch. So no need for one here.
+	dispatch(FuncRequest(LFUN_BUFFER_SWITCH, absfname));
+}
+
+
+bool GuiInclude::isValid()
+{
+	QString fname = filenameED->text();
+	if (fname.isEmpty() || !validate_listings_params().empty()) {
+		editPB->setEnabled(false);
+		return false;
+	}
+
+	int const item = typeCO->currentIndex();
+	// Are we inputting or including a LyX file?
+	if (item != 0 && item != 1) {
+		okPB->setText(qt_("&OK"));
+		return true;
+	}
+	// Do we have a LyX filename?
+	if (!isLyXFileName(fromqstr(fname))) {
+		okPB->setText(qt_("&OK"));
+		return false;
+	}
+	string const bpath = buffer().filePath();
+	// Path might be relative to current Buffer, so make absolute
+	FileName const absfname = support::makeAbsPath(fromqstr(fname), bpath);
+	// Set OK button text according to whether file already exists
+	okPB->setText(absfname.exists() ? qt_("&OK") : qt_("&Create"));
+	// enable edit button iff file is open in some Buffer
+	editPB->setEnabled(theBufferList().getBuffer(absfname));
+	return true;
 }
 
 
@@ -288,25 +353,6 @@ void GuiInclude::browse()
 }
 
 
-void GuiInclude::edit()
-{
-	if (!isValid())
-		return;
-	if (bc().policy().buttonStatus(ButtonPolicy::OKAY)) {
-		slotOK();
-		applyView();
-	} else
-		hideView();
-	dispatch(FuncRequest(LFUN_INSET_EDIT));
-}
-
-
-bool GuiInclude::isValid()
-{
-	return !filenameED->text().isEmpty() && validate_listings_params().empty();
-}
-
-
 QString GuiInclude::browse(QString const & in_name, Type in_type) const
 {
 	QString const title = qt_("Select document to include");
