@@ -16,7 +16,6 @@
 #include "FuncRequest.h"
 
 #include "support/filetools.h"
-#include "support/foreach.h"
 #include "support/FileName.h"
 
 #include "qt_helpers.h"
@@ -92,7 +91,7 @@ void GuiTexInfo::rescanClicked()
 void GuiTexInfo::viewClicked()
 {
 	// takes advantage of enum order
-	static QString const ext[] = { "cls", "sty", "bst", "bib" };
+	static QString const ext[] = { "cls", "sty", "bst", "bib", "bbx", "cbx" };
 	int const fitem = fileListLW->currentRow();
 	QStringList const & data = texdata_[activeStyle_];
 	QString file = data[fitem];
@@ -119,7 +118,8 @@ void GuiTexInfo::enableViewPB()
 void GuiTexInfo::updateStyles(TexFileType type)
 {
 	static QString const filenames[] = {
-		"clsFiles.lst", "styFiles.lst", "bstFiles.lst", "bibFiles.lst"
+		"clsFiles.lst", "styFiles.lst", "bstFiles.lst", "bibFiles.lst",
+		"bbxFiles.lst", "cbxFiles.lst"
 	};
 
 	QString const filename = filenames[type];
@@ -141,7 +141,7 @@ void GuiTexInfo::updateStyles(TexFileType type)
 	data.sort();
 
 	fileListLW->clear();
-	foreach (QString const & item, data)
+	for(QString const & item : data)
 		fileListLW->addItem(item);
 
 	activeStyle_ = type;
