@@ -243,7 +243,7 @@ GuiWorkArea::Private::Private(GuiWorkArea * parent)
   caret_visible_(false), need_resize_(false), preedit_lines_(1),
   last_pixel_ratio_(1.0), completer_(new GuiCompleter(p, p)),
   dialog_mode_(false), shell_escape_(false), read_only_(false),
-  clean_(true), externally_modified_(false)
+  clean_(true), externally_modified_(false), needs_caret_geometry_update_(true)
 {
 /* Qt on macOS and Wayland does not respect the
  * Qt::WA_OpaquePaintEvent attribute and resets the widget backing
@@ -443,16 +443,11 @@ void GuiWorkArea::startBlinkingCaret()
 	if (view().busy())
 		return;
 
-	// we cannot update geometry if not ready and we do not need to if
-	// caret is not in view.
-	if (!d->buffer_view_->buffer().undo().activeUndoGroup()) {
-		Point p;
-		int h = 0;
-		d->buffer_view_->caretPosAndHeight(p, h);
-		// Don't start blinking if the cursor isn't on screen.
-		if (!d->buffer_view_->cursorInView(p, h))
-			return;
-	}
+	// Don't start blinking if the cursor isn't on screen, unless we
+	// are not ready to know whether the cursor is on screen.
+	if (!d->buffer_view_->buffer().undo().activeUndoGroup()
+	    && !d->buffer_view_->caretInView())
+		return;
 
 	d->showCaret();
 
@@ -492,7 +487,7 @@ void GuiWorkArea::scheduleRedraw(bool update_metrics)
 
 	// update caret position, because otherwise it has to wait until
 	// the blinking interval is over
-	d->updateCaretGeometry();
+	d->resetCaret();
 
 	LYXERR(Debug::WORKAREA, "WorkArea::redraw screen");
 	viewport()->update();
@@ -588,14 +583,11 @@ void GuiWorkArea::Private::resizeBufferView()
 	// Warn our container (GuiView).
 	p->busy(true);
 
-	Point point;
-	int h = 0;
-	buffer_view_->caretPosAndHeight(point, h);
-	bool const caret_in_view = buffer_view_->cursorInView(point, h);
+	bool const caret_in_view = buffer_view_->caretInView();
 	buffer_view_->resize(p->viewport()->width(), p->viewport()->height());
 	if (caret_in_view)
 		buffer_view_->scrollToCursor();
-	updateCaretGeometry();
+	resetCaret();
 
 	// Update scrollbars which might have changed due different
 	// BufferView dimension. This is especially important when the
@@ -613,18 +605,28 @@ void GuiWorkArea::Private::resizeBufferView()
 }
 
 
+void GuiWorkArea::Private::resetCaret()
+{
+	// Don't start blinking if the cursor isn't on screen.
+	if (!buffer_view_->caretInView())
+		return;
+
+	needs_caret_geometry_update_ = true;
+	caret_visible_ = true;
+}
+
+
 void GuiWorkArea::Private::updateCaretGeometry()
 {
 	// we cannot update geometry if not ready and we do not need to if
 	// caret is not in view.
-	if (buffer_view_->buffer().undo().activeUndoGroup())
+	if (buffer_view_->buffer().undo().activeUndoGroup()
+	    || !buffer_view_->caretInView())
 		return;
 
 	Point point;
 	int h = 0;
 	buffer_view_->caretPosAndHeight(point, h);
-	if (!buffer_view_->cursorInView(point, h))
-		return;
 
 	// RTL or not RTL
 	bool l_shape = false;
@@ -646,18 +648,19 @@ void GuiWorkArea::Private::updateCaretGeometry()
 		&& completer_->completionAvailable()
 		&& !completer_->popupVisible()
 		&& !completer_->inlineVisible();
-	caret_visible_ = true;
 
 	caret_->update(point.x_, point.y_, h, l_shape, isrtl, completable);
+	needs_caret_geometry_update_ = false;
 }
 
 
+
 void GuiWorkArea::Private::showCaret()
 {
 	if (caret_visible_)
 		return;
 
-	updateCaretGeometry();
+	resetCaret();
 	p->viewport()->update();
 }
 
@@ -858,6 +861,10 @@ void GuiWorkArea::mouseReleaseEvent(QMouseEvent * e)
 
 	FuncRequest const cmd(LFUN_MOUSE_RELEASE, e->x(), e->y(),
 			q_button_state(e->button()), q_key_state(e->modifiers()));
+#if (QT_VERSION > QT_VERSION_CHECK(5,10,1) && \
+	QT_VERSION < QT_VERSION_CHECK(5,15,1))
+	d->synthetic_mouse_event_.cmd = cmd; // QtBug QAbstractScrollArea::mouseMoveEvent
+#endif
 	d->dispatch(cmd);
 	e->accept();
 }
@@ -865,6 +872,21 @@ void GuiWorkArea::mouseReleaseEvent(QMouseEvent * e)
 
 void GuiWorkArea::mouseMoveEvent(QMouseEvent * e)
 {
+#if (QT_VERSION > QT_VERSION_CHECK(5,10,1) && \
+	QT_VERSION < QT_VERSION_CHECK(5,15,1))
+	// cancel the event if the coordinates didn't change, this is due to QtBug
+	// QAbstractScrollArea::mouseMoveEvent, the event is triggered falsely when quickly
+	// double tapping a touchpad. To test: try to select a word by quickly double tapping
+	// on a touchpad while hovering the cursor over that word in the work area.
+	// This bug does not occur on Qt versions 5.10.1 and below. Only Windows seems to be affected.
+	// ML thread: https://www.mail-archive.com/lyx-devel@lists.lyx.org/msg211699.html
+	// Qt bugtracker: https://bugreports.qt.io/browse/QTBUG-85431
+	// Bug was fixed in Qt 5.15.1
+	if (e->x() == d->synthetic_mouse_event_.cmd.x() && // QtBug QAbstractScrollArea::mouseMoveEvent
+			e->y() == d->synthetic_mouse_event_.cmd.y()) // QtBug QAbstractScrollArea::mouseMoveEvent
+		return; // QtBug QAbstractScrollArea::mouseMoveEvent
+#endif
+
 	// we kill the triple click if we move
 	doubleClickTimeout();
 	FuncRequest cmd(LFUN_MOUSE_MOTION, e->x(), e->y(),
@@ -1349,8 +1371,14 @@ void GuiWorkArea::paintEvent(QPaintEvent * ev)
 	d->paintPreeditText(pain);
 
 	// and the caret
-	if (d->caret_visible_)
+	// FIXME: the code would be a little bit simpler if caret geometry
+	// was updated unconditionally. Some profiling is required to see
+	// how expensive this is (especially when idle).
+	if (d->caret_visible_) {
+		if (d->needs_caret_geometry_update_)
+			d->updateCaretGeometry();
 		d->caret_->draw(pain, d->buffer_view_->horizScrollOffset());
+	}
 
 	d->updateScreen(ev->rect());
 
