@@ -52,7 +52,8 @@ class InGuiThread : private IntoGuiThreadMover
 {
 public:
 
-	InGuiThread() {}
+	// please coverity by explicitly initalizing this variable.
+	InGuiThread() : return_value_(R()) {}
 
 	template<class F>
 	R call(F f)
@@ -93,7 +94,7 @@ public:
 	template<class F, class P1, class P2, class P3, class P4, class P5, class P6, class P7, class P8>
 	R call(F f, P1& p1, P2& p2, P3& p3, P4& p4, P5& p5, P6& p6, P7& p7, P8& p8)
 	{
-		return call(lyx::bind(f, lyx::ref(p1), lyx::ref(p2), lyx::ref(p3), lyx::ref(p4), 
+		return call(lyx::bind(f, lyx::ref(p1), lyx::ref(p2), lyx::ref(p3), lyx::ref(p4),
 			lyx::ref(p5), lyx::ref(p6), lyx::ref(p7), lyx::ref(p8)));
 	}
 
