@@ -2247,7 +2247,8 @@ void Menus::Impl::expand(MenuDefinition const & frommenu,
 				break;
 			string const format = buf->params().getDefaultOutputFormat();
 			Format const * f = theFormats().getFormat(format);
-			docstring const name = f ? f->prettyname() : from_utf8(format);
+			docstring const name = f ? translateIfPossible(f->prettyname())
+						 : from_utf8(format);
 			docstring const label = bformat(_("Export [%1$s]|E"), name);
 			MenuItem item(MenuItem::Command, toqstr(label),
 			              FuncRequest(LFUN_BUFFER_EXPORT));
