@@ -26,7 +26,7 @@
 
 #include "GraphicsTypes.h"
 
-#include <boost/signal.hpp>
+#include "support/signals.h"
 
 namespace lyx {
 
@@ -40,13 +40,15 @@ class Params;
 class Loader {
 public:
 	/// Must use the reset methods to make this instance usable.
-	Loader();
+	Loader(support::FileName const & doc_file);
 	/// The image is not transformed, just displayed as-is.
-	Loader(support::FileName const & file_with_path, bool display = true);
+	Loader(support::FileName const & doc_file, support::FileName const & file_with_path, bool display = true);
 	/// The image is transformed before display.
-	Loader(support::FileName const & file_with_path, Params const &);
+	Loader(support::FileName const & doc_file, support::FileName const & file_with_path, Params const &);
 	///
-	Loader(Loader const &);
+	Loader(support::FileName const & doc_file, Loader const &);
+	///
+	Loader(Loader const & other);
 	/// Needed for the pimpl
 	~Loader();
 
@@ -68,7 +70,7 @@ public:
 	 */
 	void startLoading() const;
 
-	/** Tries to reload the image. 
+	/** Tries to reload the image.
 	 */
 	void reload() const;
 
@@ -79,11 +81,8 @@ public:
 	void startMonitoring() const;
 	///
 	bool monitoring() const;
-	/** Returns the check checksum of filename() so that, for example, you can
-	 *  ascertain whether to output a new PostScript version of the file
-	 *  for a LaTeX run.
-	 */
-	unsigned long checksum() const;
+	///
+	void checkModifiedAsync() const;
 
 	/// How far have we got in loading the image?
 	ImageStatus status() const;
@@ -91,10 +90,10 @@ public:
 	/** Connect and you'll be informed when the loading status of the image
 	 *  changes.
 	 */
-	typedef boost::signal<void()> sig_type;
-	typedef sig_type::slot_type slot_type;
+	typedef signals2::signal<void()> sig;
+	typedef sig::slot_type slot;
 	///
-	boost::signals::connection connect(slot_type const &) const;
+	signals2::connection connect(slot const &) const;
 
 	/** The loaded image with Pixmap set.
 	 *  If the Pixmap is not yet set (see status() for why...), returns 0.
@@ -108,7 +107,7 @@ private:
 	/// Use the Pimpl idiom to hide the internals.
 	class Impl;
 	/// The pointer never changes although *pimpl_'s contents may.
-	Impl * const pimpl_;
+	Impl * pimpl_;
 };
 
 } // namespace graphics
