@@ -22,6 +22,7 @@ class Dimension;
 
 namespace graphics {
 
+class Cache;
 class PreviewLoader;
 class Image;
 
@@ -49,6 +50,8 @@ public:
 	///
 	support::FileName const & filename() const;
 
+	PreviewLoader & previewLoader() const;
+
 private:
 	/// Use the Pimpl idiom to hide the internals.
 	class Impl;
