@@ -13,7 +13,7 @@
 #define INSETARGUMENT_H
 
 
-#include "InsetCollapsable.h"
+#include "InsetCollapsible.h"
 
 
 namespace lyx {
@@ -23,16 +23,19 @@ namespace lyx {
  * InsetArgument. Used to insert a short version of sectioning header etc.
  * automatically, or other optional LaTeX arguments
  */
-class InsetArgument : public InsetCollapsable
+class InsetArgument : public InsetCollapsible
 {
 public:
 	///
 	InsetArgument(Buffer *, std::string const &);
 
+	///
+	InsetArgument const * asInsetArgument() const { return this; }
+
 	/// Outputting the parameter of a LaTeX command
-	void latexArgument(otexstream &, OutputParams const &,
-			   docstring const&, docstring const &,
-			   docstring const &) const;
+	void latexArgument(otexstream & os, OutputParams const & runparams_in,
+	                   docstring const & ldelim, docstring const & rdelim,
+	                   docstring const & presetarg) const;
 
 	std::string name() const { return name_; }
 
@@ -53,7 +56,7 @@ public:
 	///
 	int docbook(odocstream &, OutputParams const &) const { return 0; }
 	///
-	docstring xhtml(XHTMLStream &, OutputParams const &) const 
+	docstring xhtml(XHTMLStream &, OutputParams const &) const
 		{ return docstring(); }
 	///
 	void write(std::ostream & os) const;
@@ -66,9 +69,11 @@ public:
 	///
 	bool isPassThru() const { return pass_thru_; }
 	///
+	bool isTocCaption() const { return is_toc_caption_; }
+	///
 	bool resetFontEdit() const { return false; }
 	//@}
-	/// \name Public functions inherited from InsetCollapsable class
+	/// \name Public functions inherited from InsetCollapsible class
 	//@{
 	///
 	InsetLayout::InsetDecoration decoration() const;
@@ -81,11 +86,16 @@ public:
 	///
 	void setButtonLabel();
 	//@}
+	///
+	void addToToc(DocIterator const & dit, bool output_active,
+	              UpdateType utype, TocBackend & backend) const; //override
 
 private:
 	///
 	docstring toolTip(BufferView const & bv, int, int) const;
 	///
+	void fixParagraphLanguage(Language const *);
+	///
 	std::string name_;
 	///
 	docstring labelstring_;
@@ -97,10 +107,18 @@ private:
 	FontInfo labelfont_;
 	///
 	std::string decoration_;
-	///
+	/// Are we in a pass-thru context?
+	bool pass_thru_context_;
+	/// Is the argument itself have an explicitly pass-thru?
+	bool pass_thru_local_;
+	/// Effective pass-thru setting (inherited or local)
 	bool pass_thru_;
 	///
 	docstring pass_thru_chars_;
+	/// Does this argument provide content for the TOC?
+	bool is_toc_caption_;
+	/// The type of Toc this is the caption of, empty otherwise.
+	std::string caption_of_toc_;
 
 protected:
 	/// \name Protected functions inherited from Inset class
@@ -111,6 +129,8 @@ protected:
 	void doDispatch(Cursor & cur, FuncRequest & cmd);
 	///
 	Inset * clone() const { return new InsetArgument(*this); }
+	/// Is the content of this inset part of the immediate (visible) text sequence?
+	bool isPartOfTextSequence() const { return false; }
 	//@}
 };
 
