@@ -17,10 +17,10 @@
 namespace lyx {
 
 class BiblioInfo;
+class docstring_list;
 
 namespace support {
 	class FileName;
-	class FileNamePairList;
 } // namespace support
 
 /** Used to insert BibTeX's information
@@ -33,7 +33,7 @@ public:
 	~InsetBibtex();
 
 	///
-	support::FileNamePairList getBibFiles() const;
+	docstring_list getBibFiles() const;
 	///
 	bool addDatabase(docstring const &);
 	///
@@ -57,6 +57,11 @@ public:
 	int plaintext(odocstringstream & ods, OutputParams const & op,
 	              size_t max_length = INT_MAX) const;
 	///
+	void updateBuffer(ParIterator const &, UpdateType);
+	///
+	void addToToc(DocIterator const & di, bool output_active,
+				  UpdateType utype, TocBackend & backend) const;
+	///
 	void collectBibKeys(InsetIterator const &, support::FileNameList &) const;
 	///
 	void validate(LaTeXFeatures &) const;
@@ -78,15 +83,14 @@ public:
 	//@}
 
 private:
-	/// look up the path to the file using TeX
-	static support::FileName
-		getBibTeXPath(docstring const & filename, Buffer const & buf);
 	///
 	void editDatabases() const;
 	///
 	void parseBibTeXFiles(support::FileNameList &) const;
 	///
 	bool usingBiblatex() const;
+	///
+	docstring getRefLabel() const;
 
 	/// \name Private functions inherited from Inset class
 	//@{
