@@ -111,7 +111,7 @@ enum InsetCode {
 	///
 	INFO_CODE, // 45
 	///
-	COLLAPSABLE_CODE,
+	COLLAPSIBLE_CODE,
 	///
 	PHANTOM_CODE,
 	///
@@ -133,7 +133,7 @@ enum InsetCode {
 	///
 	MATH_CASES_CODE,
 	///
-	MATH_CHAR_CODE, 
+	MATH_CHAR_CODE,
 	///
 	MATH_COLOR_CODE,
 	///
@@ -217,26 +217,26 @@ enum InsetCode {
 	///
 	MATH_XARROW_CODE,
 	///
-	MATH_XYARROW_CODE,
+	MATH_XYMATRIX_CODE,
 	///
-	MATH_XYMATRIX_CODE, // 100
-	///
-	MATH_MACRO_CODE,
+	MATH_MACRO_CODE, // 100
 	///
 	ARGUMENT_PROXY_CODE,
 	///
 	PREVIEW_CODE,
 	///
-	MATH_DIAGRAM_CODE, 
+	MATH_DIAGRAM_CODE,
 	///
-	SCRIPT_CODE, // 105
+	SCRIPT_CODE,
 	///
-	IPA_CODE,
+	IPA_CODE, // 105
 	///
 	IPACHAR_CODE,
 	///
 	IPADECO_CODE,
 	///
+	MATH_CLASS_CODE,
+	///
 	INSET_CODE_SIZE
 };
 
