@@ -31,6 +31,7 @@
 #include "OutputParams.h"
 #include "output_latex.h"
 #include "output_xhtml.h"
+#include "texstream.h"
 #include "TocBackend.h"
 
 #include "frontends/alert.h"
@@ -38,7 +39,6 @@
 
 #include "graphics/PreviewLoader.h"
 
-#include "support/bind.h"
 #include "support/convert.h"
 #include "support/debug.h"
 #include "support/ExceptionMessage.h"
@@ -61,7 +61,7 @@ unsigned int const defaultLyxScale = 100;
 
 string defaultTemplateName;
 
-} // namespace anon
+} // namespace
 
 
 namespace lyx {
@@ -102,7 +102,7 @@ TempName & TempName::operator=(TempName const & other)
 			tempname_.removeFile();
 		support::TempFile f("lyxextXXXXXX.tmp");
 		f.setAutoRemove(false);
-		tempname_ = f.name(); 
+		tempname_ = f.name();
 	}
 	return *this;
 }
@@ -118,6 +118,7 @@ support::FileName TempName::operator()() const
 
 InsetExternalParams::InsetExternalParams()
 	: display(true),
+	  preview_mode(PREVIEW_OFF),
 	  lyxscale(defaultLyxScale),
 	  draft(false)
 {
@@ -147,7 +148,7 @@ void clearIfNotFound(T & data, external::TransformID value,
 		data = T();
 }
 
-} // namespace anon
+} // namespace
 
 
 void InsetExternalParams::settemplate(string const & name)
@@ -169,7 +170,7 @@ void InsetExternalParams::settemplate(string const & name)
 	clearIfNotFound(resizedata,   external::Resize, ids);
 	clearIfNotFound(rotationdata, external::Rotate, ids);
 
-	// 
+	//
 	preview_mode = et->preview_mode;
 }
 
@@ -287,17 +288,23 @@ bool InsetExternalParams::read(Buffer const & buffer, Lexer & lex)
 			filename = buffer.getReferencedFileName(name);
 			break;
 		}
-		
+
 		case EX_DISPLAY: {
 			lex.next();
 			display = lex.getString() != "false";
 			break;
 		}
 
-		case EX_LYXSCALE:
+		case EX_LYXSCALE: {
 			lex.next();
-			lyxscale = lex.getInteger();
+			int const ls = lex.getInteger();
+			// negative values are not accepted.
+			if (ls >= 0)
+				lyxscale = ls;
+			else
+				lex.printError("ExternalInset::read: Wrong lyxscale: $$Token");
 			break;
+		}
 
 		case EX_DRAFT:
 			draft = true;
@@ -407,8 +414,7 @@ docstring screenLabel(InsetExternalParams const & params,
 	return gui;
 }
 
-} // namespace anon
-
+} // namespace
 
 
 InsetExternal::InsetExternal(Buffer * buf)
@@ -420,7 +426,6 @@ InsetExternal::InsetExternal(Buffer * buf)
 // Mouse hover is not copied and remains empty
 InsetExternal::InsetExternal(InsetExternal const & other)
 	: Inset(other),
-	  boost::signals::trackable(),
 	  params_(other.params_),
 	  renderer_(other.renderer_->clone(this))
 {}
@@ -500,13 +505,12 @@ bool InsetExternal::getStatus(Cursor & cur, FuncRequest const & cmd,
 
 
 void InsetExternal::addToToc(DocIterator const & cpit, bool output_active,
-							 UpdateType) const
+							 UpdateType, TocBackend & backend) const
 {
-	DocIterator pit = cpit;
-	pit.push_back(CursorSlice(const_cast<InsetExternal &>(*this)));
-	shared_ptr<Toc> toc = buffer().tocBackend().toc("external");
 	docstring str = screenLabel(params_, buffer());
-	toc->push_back(TocItem(pit, 0, str, output_active));
+	TocBuilder & b = backend.builder("external");
+	b.pushItem(cpit, str, output_active);
+	b.pop();
 }
 
 
@@ -554,7 +558,7 @@ graphics::Params get_grfx_params(InsetExternalParams const & eparams)
 	return gparams;
 }
 
-} // namespace anon
+} // namespace
 
 
 static bool isPreviewWanted(InsetExternalParams const & params)
@@ -565,9 +569,8 @@ static bool isPreviewWanted(InsetExternalParams const & params)
 
 static docstring latexString(InsetExternal const & inset)
 {
-	TexRow texrow;
 	odocstringstream ods;
-	otexstream os(ods, texrow);
+	otexstream os(ods);
 	// We don't need to set runparams.encoding since it is not used by
 	// latex().
 	OutputParams runparams(0);
@@ -637,7 +640,7 @@ void InsetExternal::updatePreview() const
 			renderer_.reset(new RenderButton);
 			button_ptr = renderer_->asButton();
 		}
-		button_ptr->update(screenLabel(params_, buffer()), true);
+		button_ptr->update(screenLabel(params_, buffer()), true, false);
 		return;
 	}
 
@@ -647,14 +650,13 @@ void InsetExternal::updatePreview() const
 		LASSERT(false, return);
 		break;
 	case PREVIEW_INSTANT: {
-		renderer_.reset(new RenderMonitoredPreview(this));
+		renderer_ = make_unique<RenderMonitoredPreview>(this);
 		RenderMonitoredPreview * preview_ptr = renderer_->asMonitoredPreview();
-		preview_ptr->fileChanged(bind(&InsetExternal::fileChanged, this));
-		if (preview_ptr->monitoring())
-			preview_ptr->stopMonitoring();
+		// This connection is closed at the same time as this is destroyed.
+		preview_ptr->connect([=]() { fileChanged(); });
 		add_preview_and_start_loading(*preview_ptr, *this, buffer());
 		break;
-	} 
+	}
 	case PREVIEW_GRAPHICS: {
 		RenderGraphic * graphic_ptr = renderer_->asGraphic();
 		if (!graphic_ptr) {
@@ -749,10 +751,9 @@ int InsetExternal::plaintext(odocstringstream & os,
 	if (runparams.for_tooltip)
 		return 0;
 
-	TexRow texrow;
-	otexstream ots(os, texrow);
 	bool const external_in_tmpdir = !runparams.nice;
 	bool const dryrun = runparams.dryrun || runparams.inComment;
+	otexstream ots(os);
 	ots << '\n'; // output external material on a new line
 	external::writeExternal(params_, "Ascii", buffer(), ots,
 				*(runparams.exportdata), external_in_tmpdir, dryrun);
@@ -763,11 +764,10 @@ int InsetExternal::plaintext(odocstringstream & os,
 int InsetExternal::docbook(odocstream & os,
 			   OutputParams const & runparams) const
 {
-	TexRow texrow;
-	odocstringstream ods;
-	otexstream ots(ods, texrow);
 	bool const external_in_tmpdir = !runparams.nice;
 	bool const dryrun = runparams.dryrun || runparams.inComment;
+	odocstringstream ods;
+	otexstream ots(ods);
 	external::writeExternal(params_, "DocBook", buffer(), ots,
 				*(runparams.exportdata), external_in_tmpdir, dryrun);
 	os << ods.str();
@@ -780,10 +780,9 @@ docstring InsetExternal::xhtml(XHTMLStream & xs,
 {
 	bool const external_in_tmpdir = !runparams.nice;
 	bool const dryrun = runparams.dryrun || runparams.inComment;
-    TexRow texrow;
-    odocstringstream ods;
-    otexstream ots(ods, texrow);
-    external::writeExternal(params_, "XHTML", buffer(), ots,
+	odocstringstream ods;
+	otexstream ots(ods);
+	external::writeExternal(params_, "XHTML", buffer(), ots,
 				       *(runparams.exportdata), external_in_tmpdir, dryrun);
 	xs << XHTMLStream::ESCAPE_NONE << ods.str();
 	return docstring();
@@ -849,10 +848,8 @@ void InsetExternal::validate(LaTeXFeatures & features) const
 
 	external::TemplateManager & etm = external::TemplateManager::get();
 
-	it  = cit->second.preambleNames.begin();
-	end = cit->second.preambleNames.end();
-	for (; it != end; ++it) {
-		string const preamble = etm.getPreambleDefByName(*it);
+	for (string const & name : cit->second.preambleNames) {
+		docstring const preamble = etm.getPreambleDefByName(name);
 		if (!preamble.empty())
 			features.addPreambleSnippet(preamble);
 	}
@@ -860,7 +857,7 @@ void InsetExternal::validate(LaTeXFeatures & features) const
 
 
 void InsetExternal::addPreview(DocIterator const & /*inset_pos*/,
-	graphics::PreviewLoader & ploader) const	
+                               graphics::PreviewLoader & ploader) const
 {
 	RenderMonitoredPreview * const ptr = renderer_->asMonitoredPreview();
 	if (!ptr)
