@@ -20,6 +20,7 @@
 #include "MetricsInfo.h"
 #include "OutputParams.h"
 #include "output_xhtml.h"
+#include "texstream.h"
 #include "Text.h"
 #include "TextMetrics.h"
 
@@ -102,8 +103,6 @@ void InsetNewpage::metrics(MetricsInfo & mi, Dimension & dim) const
 	dim.asc = defaultRowHeight();
 	dim.des = defaultRowHeight();
 	dim.wid = mi.base.textwidth;
-	// Cache the inset dimension. 
-	setDimCache(mi, dim);
 }
 
 
@@ -164,7 +163,7 @@ bool InsetNewpage::getStatus(Cursor & cur, FuncRequest const & cmd,
 			InsetNewpageParams params;
 			string2params(to_utf8(cmd.argument()), params);
 			status.setOnOff(params_.kind == params.kind);
-		} 
+		}
 		status.setEnabled(true);
 		return true;
 	default:
@@ -220,21 +219,21 @@ void InsetNewpage::latex(otexstream & os, OutputParams const & runparams) const
 	} else {
 		switch (params_.kind) {
 		case InsetNewpageParams::NEWPAGE:
-			os << "\\newpage{}";
+			os << "\\newpage" << termcmd;
 			break;
 		case InsetNewpageParams::PAGEBREAK:
 			if (runparams.moving_arg)
 				os << "\\protect";
-			os << "\\pagebreak{}";
+			os << "\\pagebreak" << termcmd;
 			break;
 		case InsetNewpageParams::CLEARPAGE:
-			os << "\\clearpage{}";
+			os << "\\clearpage" << termcmd;
 			break;
 		case InsetNewpageParams::CLEARDOUBLEPAGE:
-			os << "\\cleardoublepage{}";
+			os << "\\cleardoublepage" << termcmd;
 			break;
 		default:
-			os << "\\newpage{}";
+			os << "\\newpage" << termcmd;
 			break;
 		}
 	}
