@@ -28,6 +28,7 @@
 #include "Lexer.h"
 #include "MetricsInfo.h"
 #include "OutputParams.h"
+#include "texstream.h"
 #include "TextClass.h"
 
 #include "support/docstream.h"
@@ -84,7 +85,7 @@ PhantomTranslatorLoc const & phantomtranslator_loc()
 	return translator;
 }
 
-} // anon
+} // namespace
 
 
 InsetPhantomParams::InsetPhantomParams()
@@ -115,7 +116,7 @@ void InsetPhantomParams::read(Lexer & lex)
 /////////////////////////////////////////////////////////////////////
 
 InsetPhantom::InsetPhantom(Buffer * buf, string const & label)
-	: InsetCollapsable(buf)
+	: InsetCollapsible(buf)
 {
 	setDrawFrame(false);
 	params_.type = phantomtranslator().find(label);
@@ -134,19 +135,10 @@ docstring InsetPhantom::layoutName() const
 }
 
 
-void InsetPhantom::metrics(MetricsInfo & mi, Dimension & dim) const
-{
-	InsetCollapsable::metrics(mi, dim);
-
-	// cache the inset dimension
-	setDimCache(mi, dim);
-}
-
-
 void InsetPhantom::draw(PainterInfo & pi, int x, int y) const
 {
 	// draw the text
-	InsetCollapsable::draw(pi, x, y);
+	InsetCollapsible::draw(pi, x, y);
 
 	// draw the inset marker
 	drawMarkers(pi, x, y);
@@ -156,7 +148,7 @@ void InsetPhantom::draw(PainterInfo & pi, int x, int y) const
 	ColorCode const origcol = pi.base.font.color();
 	pi.base.font.setColor(Color_special);
 	pi.base.font.setColor(origcol);
-	Dimension const dim = Inset::dimension(*pi.base.bv);
+	Dimension const dim = dimension(*pi.base.bv);
 
 	if (params_.type == InsetPhantomParams::Phantom ||
 		params_.type == InsetPhantomParams::VPhantom) {
@@ -230,14 +222,14 @@ void InsetPhantom::draw(PainterInfo & pi, int x, int y) const
 void InsetPhantom::write(ostream & os) const
 {
 	params_.write(os);
-	InsetCollapsable::write(os);
+	InsetCollapsible::write(os);
 }
 
 
 void InsetPhantom::read(Lexer & lex)
 {
 	params_.read(lex);
-	InsetCollapsable::read(lex);
+	InsetCollapsible::read(lex);
 }
 
 
@@ -272,7 +264,7 @@ void InsetPhantom::doDispatch(Cursor & cur, FuncRequest & cmd)
 		break;
 
 	default:
-		InsetCollapsable::doDispatch(cur, cmd);
+		InsetCollapsible::doDispatch(cur, cmd);
 		break;
 	}
 }
@@ -297,7 +289,7 @@ bool InsetPhantom::getStatus(Cursor & cur, FuncRequest const & cmd,
 		return true;
 
 	default:
-		return InsetCollapsable::getStatus(cur, cmd, flag);
+		return InsetCollapsible::getStatus(cur, cmd, flag);
 	}
 }
 
@@ -328,7 +320,7 @@ void InsetPhantom::latex(otexstream & os, OutputParams const & runparams) const
 		os << "\\phantom{";
 		break;
 	}
-	InsetCollapsable::latex(os, runparams);
+	InsetCollapsible::latex(os, runparams);
 	os << "}";
 }
 
@@ -350,7 +342,7 @@ int InsetPhantom::plaintext(odocstringstream & os,
 		os << '[' << buffer().B_("phantom") << ":";
 		break;
 	}
-	InsetCollapsable::plaintext(os, runparams, max_length);
+	InsetCollapsible::plaintext(os, runparams, max_length);
 	os << "]";
 
 	return PLAINTEXT_NEWLINE;
@@ -369,7 +361,7 @@ int InsetPhantom::docbook(odocstream & os, OutputParams const & runparams) const
 		break;
 	}
 	os << "<" + cmdname + ">";
-	int const i = InsetCollapsable::docbook(os, runparams);
+	int const i = InsetCollapsible::docbook(os, runparams);
 	os << "</" + cmdname + ">";
 
 	return i;
