@@ -353,7 +353,7 @@ docstring InsetQuotesParams::getLaTeXQuote(char_type c, string const & op,
 	case 0x2019: {// '
 		if (op == "int")
 			// This macro is redefined in rtl mode
-			res = rtl ? "\\textquoteright" : "\\textquoteleft";
+			res = rtl ? "\\textquoteleft" : "\\textquoteright";
 		else
 			res = "'";
 		break;
@@ -361,7 +361,7 @@ docstring InsetQuotesParams::getLaTeXQuote(char_type c, string const & op,
 	case 0x2018: {// `
 		if (op == "int")
 			// This macro is redefined in rtl mode
-			res = rtl ? "\\textquoteleft" : "\\textquoteright";
+			res = rtl ? "\\textquoteright" : "\\textquoteleft";
 		else
 			res = "`";
 		break;
@@ -396,7 +396,7 @@ docstring InsetQuotesParams::getLaTeXQuote(char_type c, string const & op,
 	case 0x201d: {// ''
 		if (op == "int")
 			// This macro is redefined in rtl mode
-			res = rtl ? "\\textquotedblright" : "\\textquotedblleft";
+			res = rtl ? "\\textquotedblleft" : "\\textquotedblright";
 		else
 			res = "''";
 		break;
@@ -404,7 +404,7 @@ docstring InsetQuotesParams::getLaTeXQuote(char_type c, string const & op,
 	case 0x201c: {// ``
 		if (op == "int")
 			// This macro is redefined in rtl mode
-			res = rtl ? "\\textquotedblleft" : "\\textquotedblright";
+			res = rtl ? "\\textquotedblright" : "\\textquotedblleft";
 		else
 			res = "``";
 		break;
@@ -880,6 +880,10 @@ void InsetQuotes::latex(otexstream & os, OutputParams const & runparams) const
 			qstr = from_ascii("\\og");
 		else
 			qstr = from_ascii("\\fg");
+	} else if (runparams.use_hyperref && runparams.moving_arg) {
+		// Use internal commands in headings with hyperref
+		// (ligatures not featured in PDF strings)
+		qstr = quoteparams.getLaTeXQuote(quotechar, "int", rtl_);
 	} else if (fontenc_ == "T1"
 		   && !runparams.local_font->language()->internalFontEncoding()) {
 		// Quotation marks for T1 font encoding
