@@ -30,6 +30,8 @@ public:
 	enum Kind {
 		/// Optional hyphenation point (\-)
 		HYPHENATION,
+		/// Optional line wrap point without hyphen (ZWSP)
+		ALLOWBREAK,
 		/// Ligature break point (\textcompwordmark)
 		LIGATURE_BREAK,
 		/// ... (\ldots)
@@ -59,6 +61,8 @@ public:
 	///
 	Kind kind() const;
 	///
+	docstring toolTip(BufferView const & bv, int x, int y) const;
+	///
 	void metrics(MetricsInfo &, Dimension &) const;
 	///
 	void draw(PainterInfo & pi, int x, int y) const;
@@ -78,7 +82,7 @@ public:
 	///
 	void toString(odocstream &) const;
 	///
-	bool isInToc() const { return true; }	
+	bool isInToc() const { return true; }
 	///
 	void forOutliner(docstring &, size_t const, bool const) const;
 	///
@@ -89,11 +93,13 @@ public:
 	void validate(LaTeXFeatures &) const;
 
 	/// should this inset be handled like a normal character?
-	bool isChar() const { return true; }
+	bool isChar() const;
 	/// is this equivalent to a letter?
 	bool isLetter() const;
 	/// should we break lines after this inset?
 	bool isLineSeparator() const;
+	/// Is the content of this inset part of the immediate (visible) text sequence?
+	bool isPartOfTextSequence() const { return isChar(); }
 private:
 	Inset * clone() const { return new InsetSpecialChar(*this); }
 
