@@ -79,14 +79,14 @@ using graphics::PreviewLoader;
 /////////////////////////////////////////////////////////////////////
 
 InsetText::InsetText(Buffer * buf, UsePlain type)
-	: Inset(buf), drawFrame_(false), frame_color_(Color_insetframe),
-	text_(this, type == DefaultLayout)
+	: Inset(buf), drawFrame_(false), intitle_context_(false),
+	  frame_color_(Color_insetframe), text_(this, type == DefaultLayout)
 {
 }
 
 
 InsetText::InsetText(InsetText const & in)
-	: Inset(in), text_(this, in.text_)
+	: Inset(in), intitle_context_(false), text_(this, in.text_)
 {
 	drawFrame_ = in.drawFrame_;
 	frame_color_ = in.frame_color_;
@@ -318,10 +318,8 @@ void InsetText::doDispatch(Cursor & cur, FuncRequest & cmd)
 		bool const main_inset = text_.isMainText();
 		bool const target_inset = cmd.argument().empty()
 			|| cmd.getArg(0) == insetName(lyxCode());
-		// cur.inset() is the tabular when this is a single cell (bug #9954)
-		bool const one_cell = cur.inset().nargs() == 1;
 
-		if (!main_inset && target_inset && one_cell) {
+		if (!main_inset && target_inset) {
 			// Text::dissolveInset assumes that the cursor
 			// is inside the Inset.
 			if (&cur.inset() != this)
@@ -351,11 +349,9 @@ bool InsetText::getStatus(Cursor & cur, FuncRequest const & cmd,
 		bool const main_inset = text_.isMainText();
 		bool const target_inset = cmd.argument().empty()
 			|| cmd.getArg(0) == insetName(lyxCode());
-		// cur.inset() is the tabular when this is a single cell (bug #9954)
-		bool const one_cell = cur.inset().nargs() == 1;
 
 		if (target_inset)
-			status.setEnabled(!main_inset && one_cell);
+			status.setEnabled(!main_inset);
 		return target_inset;
 	}
 
@@ -505,6 +501,9 @@ void InsetText::latex(otexstream & os, OutputParams const & runparams) const
 	// Output the contents of the inset
 	latexParagraphs(buffer(), text_, os, rp);
 	runparams.encoding = rp.encoding;
+	// These need to be passed upstream as well
+	runparams.need_maketitle = rp.need_maketitle;
+	runparams.have_maketitle = rp.have_maketitle;
 
 	if (!il.rightdelim().empty())
 		os << il.rightdelim();
@@ -794,6 +793,17 @@ void InsetText::updateBuffer(ParIterator const & it, UpdateType utype)
 			cnt.restoreLastLayout();
 			// FIXME cnt.restoreLastCounter()?
 		}
+		// Record in this inset is embedded in a title layout
+		// This is needed to decide when \maketitle is output.
+		intitle_context_ = it.paragraph().layout().intitle;
+		// Also check embedding layouts
+		size_t const n = it.depth();
+		for (size_t i = 0; i < n; ++i) {
+			if (it[i].paragraph().layout().intitle) {
+				intitle_context_ = true;
+				break;
+			}
+		}
 	} else {
 		DocumentClass const & tclass = buffer().masterBuffer()->params().documentClass();
 		// Note that we do not need to call:
