@@ -24,6 +24,7 @@
 #include "MetricsInfo.h"
 #include "OutputParams.h"
 #include "output_xhtml.h"
+#include "texstream.h"
 #include "Text.h"
 
 #include "support/debug.h"
@@ -45,7 +46,7 @@ namespace {
 
 int const ADD_TO_VSPACE_WIDTH = 5;
 
-} // namespace anon
+} // namespace
 
 
 InsetVSpace::InsetVSpace(VSpace const & space)
@@ -90,10 +91,10 @@ bool InsetVSpace::getStatus(Cursor & cur, FuncRequest const & cmd,
 				: "vspace 1" + string(stringFromUnit(Length::defaultUnit()));
 			InsetVSpace::string2params(arg, vspace);
 			status.setOnOff(vspace == space_);
-		} 
+		}
 		status.setEnabled(true);
 		return true;
-	
+
 	default:
 		return Inset::getStatus(cur, cmd, status);
 	}
@@ -149,8 +150,6 @@ void InsetVSpace::metrics(MetricsInfo & mi, Dimension & dim) const
 	dim.asc = height / 2 + (a - d) / 2; // align cursor with the
 	dim.des = height - dim.asc;         // label text
 	dim.wid = ADD_TO_VSPACE_WIDTH + 2 * vspace_arrow_size + 5 + w;
-	// Cache the inset dimension. 
-	setDimCache(mi, dim);
 }
 
 
