@@ -33,7 +33,7 @@ public:
 	virtual void draw(PainterInfo & pi, int x, int y) const;
 
 	/// Provide the text for the button
-	void update(docstring const &, bool editable);
+	void update(docstring const &, bool editable, bool inherit_font);
 
 	/// The "sensitive area" box, i.e., the button area
 	Box box() const { return button_box_; }
@@ -47,6 +47,7 @@ private:
 	/// The stored data.
 	docstring text_;
 	bool editable_;
+	bool inherit_font_;
 	Box button_box_;
 };
 
