@@ -13,15 +13,18 @@
 
 #include "InsetMath.h"
 #include "MathData.h"
+#include "MathRow.h"
 #include "MathStream.h"
 
+#include "MetricsInfo.h"
+
 #include "support/debug.h"
 #include "support/docstream.h"
 #include "support/gettext.h"
+#include "support/lassert.h"
 #include "support/lstrings.h"
 #include "support/textutils.h"
 
-#include "support/lassert.h"
 
 using namespace std;
 
@@ -49,12 +52,33 @@ MathData const & InsetMath::cell(idx_type) const
 }
 
 
+MathClass InsetMath::mathClass() const
+{
+	return MC_ORD;
+}
+
+
+InsetMath::marker_type InsetMath::marker(BufferView const *) const
+{
+	return nargs() > 0 ? MARKER : NO_MARKER;
+}
+
+
+bool InsetMath::addToMathRow(MathRow & mrow, MetricsInfo & mi) const
+{
+	MathRow::Element e(mi, MathRow::INSET, mathClass());
+	e.inset = this;
+	e.marker = mi.base.macro_nesting ? NO_MARKER : marker(mi.base.bv);
+	mrow.push_back(e);
+	return true;
+}
+
+
 void InsetMath::dump() const
 {
 	lyxerr << "---------------------------------------------" << endl;
 	odocstringstream os;
-	TexRow texrow(false);
-	otexrowstream ots(os,texrow);
+	otexrowstream ots(os);
 	WriteStream wi(ots, false, true, WriteStream::wsDefault);
 	write(wi);
 	lyxerr << to_utf8(os.str());
@@ -86,7 +110,7 @@ void InsetMath::write(WriteStream & os) const
 }
 
 
-int InsetMath::plaintext(odocstringstream &, 
+int InsetMath::plaintext(odocstringstream &,
         OutputParams const &, size_t) const
 {
 	// all math plain text output shall take place in InsetMathHull
@@ -158,8 +182,7 @@ HullType InsetMath::getType() const
 ostream & operator<<(ostream & os, MathAtom const & at)
 {
 	odocstringstream oss;
-	TexRow texrow(false);
-	otexrowstream ots(oss,texrow);
+	otexrowstream ots(oss);
 	WriteStream wi(ots, false, false, WriteStream::wsDefault);
 	at->write(wi);
 	return os << to_utf8(oss.str());
@@ -168,8 +191,7 @@ ostream & operator<<(ostream & os, MathAtom const & at)
 
 odocstream & operator<<(odocstream & os, MathAtom const & at)
 {
-	TexRow texrow(false);
-	otexrowstream ots(os,texrow);
+	otexrowstream ots(os);
 	WriteStream wi(ots, false, false, WriteStream::wsDefault);
 	at->write(wi);
 	return os;
