@@ -42,7 +42,7 @@ public:
 	void infoize(odocstream & os) const;
 	///
 	void normalize(NormalStream &) const;
-	// Don't need mathmlize or htmlize, as this is handled by 
+	// Don't need mathmlize or htmlize, as this is handled by
 	// InsetMathMatrix after being extracted in MathExtern.
 	// void mathmlize(MathStream &) const;
 	// void htmlize(HTMLStream &) const;
@@ -54,8 +54,12 @@ public:
 	char const * name_left() const;
 	///
 	char const * name_right() const;
-	/// 
-	bool handlesMulticolumn() const { return true; } //override 
+	///
+	int leftMargin() const { return 6; } //override
+	///
+	int rightMargin() const { return 8; } //override
+	///
+	bool handlesMulticolumn() const { return true; } //override
 
 private:
 	virtual Inset * clone() const;
