@@ -24,6 +24,8 @@ public:
 	InsetMathBig(docstring const & name, docstring const & delim);
 	///
 	docstring name() const;
+	/// class is different for l(eft), r(ight) and m(iddle)
+	MathClass mathClass() const;
 	///
 	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
@@ -50,6 +52,8 @@ private:
 	size_type size() const;
 	///
 	double increase() const;
+	/// name with leading backslash stripped
+	docstring word() const;
 
 	/// \\bigl or what?
 	docstring const name_;
