@@ -25,6 +25,8 @@ public:
 	///
 	InsetMathFracBase(Buffer * buf, idx_type ncells = 2);
 	///
+	marker_type marker(BufferView const *) const { return MARKER2; }
+	///
 	bool idxUpDown(Cursor &, bool up) const;
 	///
 	bool idxBackward(Cursor &) const { return false; }
@@ -62,6 +64,8 @@ public:
 	///
 	bool idxBackward(Cursor &) const;
 	///
+	MathClass mathClass() const;
+	///
 	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void draw(PainterInfo &, int x, int y) const;
@@ -91,7 +95,10 @@ public:
 	void htmlize(HtmlStream &) const;
 	///
 	void validate(LaTeXFeatures & features) const;
-public:
+private:
+	/// vertical displacement
+	int dy(FontInfo & fi) const;
+	///
 	Inset * clone() const;
 	///
 	Kind kind_;
@@ -117,13 +124,12 @@ public:
 	void write(WriteStream & os) const;
 	///
 	void normalize(NormalStream &) const;
+	/// Generalized fractions are of inner class (see The TeXbook, p.292)
+	MathClass mathClass() const { return MC_INNER; }
 	///
 	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void draw(PainterInfo &, int x, int y) const;
-	/// draw decorations.
-	void drawDecoration(PainterInfo & pi, int x, int y) const
-	{ drawMarkers2(pi, x, y); }
 	///
 	bool extraBraces() const;
 	///
