@@ -272,6 +272,8 @@ void initSymbols()
 					tmp.requires = "wasysym";
 				else if (tmp.inset == "mathscr")
 					tmp.requires = "mathrsfs";
+				else if (tmp.inset == "mathds")
+					tmp.requires = "dsfont";
 			}
 
 			// symbol font is not available sometimes
@@ -714,10 +716,4 @@ bool createInsetMath_fromDialogStr(docstring const & str, MathData & ar)
 }
 
 
-bool isAsciiOrMathAlpha(char_type c)
-{
-	return isASCII(c) || Encodings::isMathAlpha(c);
-}
-
-
 } // namespace lyx
