@@ -1017,7 +1017,7 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 
 		else if (t.cat() == catOther) {
 			char_type c = t.character();
-			if (isAsciiOrMathAlpha(c)
+			if (!Encodings::isUnicodeTextOnly(c)
 			    || mode_ & Parse::VERBATIM
 			    || !(mode_ & Parse::USETEXT)
 			    || mode == InsetMath::TEXT_MODE) {
@@ -1026,7 +1026,7 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 				MathAtom at = createInsetMath("text", buf);
 				at.nucleus()->cell(0).push_back(MathAtom(new InsetMathChar(c)));
 				while (nextToken().cat() == catOther
-				       && !isAsciiOrMathAlpha(nextToken().character())) {
+				       && Encodings::isUnicodeTextOnly(nextToken().character())) {
 					c = getToken().character();
 					at.nucleus()->cell(0).push_back(MathAtom(new InsetMathChar(c)));
 				}
@@ -1606,7 +1606,7 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 				docstring const halign = parse_verbatim_item();
 				cell->push_back(MathAtom(new InsetMathArray(buf, name,
 					InsetMathGrid::guessColumns(halign), 1, (char)valign[0], halign)));
-				parse2(cell->back(), FLAG_END, mode, false);
+				parse2(cell->back(), FLAG_END, InsetMath::MATH_MODE, false);
 			}
 
 			else if (name == "tabular") {
@@ -2077,7 +2077,7 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 							Encodings::MATH_CMD | Encodings::TEXT_CMD,
 							is_combining, termination);
 					}
-					if (c) {
+					if (c && buf->params().encoding().encodable(c)) {
 						if (termination) {
 							if (nextToken().cat() == catBegin) {
 								getToken();
