@@ -82,6 +82,7 @@ namespace {
 /*
  * Internal struct of a drawing: code n x1 y1 ... xn yn, where code is:
  * 0 = end, 1 = line, 2 = polyline, 3 = square line, 4 = square polyline
+ * 5 = rounded thick line (i.e. dot for short line)
  */
 
 
@@ -293,9 +294,18 @@ double const hline[] = {
 };
 
 
+double const dot[] = {
+//	1, 0.5, 0.2, 0.5, 0.2,
+//	1, 0.4, 0.4, 0.6, 0.4,
+//	1, 0.5, 0.5, 0.5, 0.5,
+	5, 0.4, 0.4, 0.6, 0.4,
+	0
+};
+
+
 double const ddot[] = {
-	1, 0.2, 0.5, 0.3, 0.5,
-	1, 0.7, 0.5, 0.8, 0.5,
+	5, 0.0, 0.4, 0.3, 0.4,
+	5, 0.6, 0.4, 1.0, 0.4,
 	0
 };
 
@@ -333,12 +343,6 @@ double const dline3[] = {
 };
 
 
-double const hlinesmall[] = {
-	1, 0.4, 0.5, 0.6, 0.5,
-	0
-};
-
-
 double const ring[] = {
 	2, 5,
 	0.5, 0.8,  0.8, 0.5,  0.5, 0.2,  0.2, 0.5,  0.5, 0.8,
@@ -457,7 +461,7 @@ named_deco_struct deco_table[] = {
 	{"acute",          slash,      0 },
 	{"tilde",          tilde,      0 },
 	{"bar",            hline,      0 },
-	{"dot",            hlinesmall, 0 },
+	{"dot",            dot,        0 },
 	{"check",          angle,      1 },
 	{"breve",          parenth,    1 },
 	{"vec",            arrow,      3 },
@@ -513,6 +517,12 @@ int mathed_font_em(FontInfo const & font)
 	return theFontMetrics(font).em();
 }
 
+
+int mathed_font_x_height(FontInfo const & font)
+{
+	return theFontMetrics(font).ascent('x');
+}
+
 /* The math units. Quoting TeX by Topic, p.205:
  *
  * Spacing around mathematical objects is measured in mu units. A mu
@@ -617,7 +627,7 @@ void mathed_draw_deco(PainterInfo & pi, int x, int y, int w, int h,
 
 	for (int i = 0; d[i]; ) {
 		int code = int(d[i++]);
-		if (code & 1) {  // code == 1 || code == 3
+		if (code & 1) {  // code == 1 || code == 3 || code == 5
 			double xx = d[i++];
 			double yy = d[i++];
 			double x2 = d[i++];
@@ -631,6 +641,16 @@ void mathed_draw_deco(PainterInfo & pi, int x, int y, int w, int h,
 				int(x + xx + 0.5), int(y + yy + 0.5),
 				int(x + x2 + 0.5), int(y + y2 + 0.5),
 				pi.base.font.color());
+			if (code == 5) {  // thicker, but rounded
+				pi.pain.line(
+					int(x + xx + 0.5+1), int(y + yy + 0.5-1),
+					int(x + x2 + 0.5-1), int(y + y2 + 0.5-1),
+				pi.base.font.color());
+				pi.pain.line(
+					int(x + xx + 0.5+1), int(y + yy + 0.5+1),
+					int(x + x2 + 0.5-1), int(y + y2 + 0.5+1),
+				pi.base.font.color());
+			}
 		} else {
 			int xp[32];
 			int yp[32];
@@ -653,9 +673,9 @@ void mathed_draw_deco(PainterInfo & pi, int x, int y, int w, int h,
 }
 
 
-void mathedSymbolDim(MetricsBase & mb, Dimension & dim, latexkeys const * sym)
+int mathedSymbolDim(MetricsBase & mb, Dimension & dim, latexkeys const * sym)
 {
-	LASSERT((bool)sym, return);
+	LASSERT((bool)sym, return 0);
 	//lyxerr << "metrics: symbol: '" << sym->name
 	//	<< "' in font: '" << sym->inset
 	//	<< "' drawn as: '" << sym->draw
@@ -665,8 +685,15 @@ void mathedSymbolDim(MetricsBase & mb, Dimension & dim, latexkeys const * sym)
 		sym->extra == "mathalpha" &&
 		mb.fontname == "mathit";
 	std::string const font = italic_upcase_greek ? "cmm" : sym->inset;
-	Changer dummy = mb.changeFontSet(font);
+	bool const change_font = font != "cmr" ||
+				(mb.fontname != "mathbb" &&
+				 mb.fontname != "mathds" &&
+				 mb.fontname != "mathfrak" &&
+				 mb.fontname != "mathcal" &&
+				 mb.fontname != "mathscr");
+	Changer dummy = change_font ? mb.changeFontSet(font) : Changer();
 	mathed_string_dim(mb.font, sym->draw, dim);
+	return mathed_char_kerning(mb.font, sym->draw.back());
 }
 
 
@@ -682,8 +709,13 @@ void mathedSymbolDraw(PainterInfo & pi, int x, int y, latexkeys const * sym)
 		sym->extra == "mathalpha" &&
 		pi.base.fontname == "mathit";
 	std::string const font = italic_upcase_greek ? "cmm" : sym->inset;
-
-	Changer dummy = pi.base.changeFontSet(font);
+	bool const change_font = font != "cmr" ||
+				(pi.base.fontname != "mathbb" &&
+				 pi.base.fontname != "mathds" &&
+				 pi.base.fontname != "mathfrak" &&
+				 pi.base.fontname != "mathcal" &&
+				 pi.base.fontname != "mathscr");
+	Changer dummy = change_font ? pi.base.changeFontSet(font) : Changer();
 	pi.draw(x, y, sym->draw);
 }
 
@@ -755,6 +787,8 @@ fontinfo fontinfos[] = {
 			  inh_shape, Color_math},
 	{"mathbb",        MSB_FAMILY, inh_series,
 			  inh_shape, Color_math},
+	{"mathds",        DS_FAMILY, inh_series,
+			  inh_shape, Color_math},
 	{"mathtt",        TYPEWRITER_FAMILY, inh_series,
 			  inh_shape, Color_math},
 	{"mathit",        inh_family, inh_series,
