@@ -32,6 +32,8 @@
 #include "support/lstrings.h"
 #include "support/lyxalgo.h"
 
+#include <iostream>
+
 using namespace std;
 using namespace lyx::support;
 
@@ -106,15 +108,15 @@ ParagraphList::const_iterator makeParagraph(
 	for (ParagraphList::const_iterator par = pbegin; par != pend; ++par) {
 		if (par != pbegin)
 			os << '\n';
-		bool const default_or_plain = 
-			(buf.params().documentClass().isDefaultLayout(par->layout()) 
+		bool const default_or_plain =
+			(buf.params().documentClass().isDefaultLayout(par->layout())
 				|| buf.params().documentClass().isPlainLayout(par->layout()));
 		if (default_or_plain && par->emptyTag()) {
-			par->simpleDocBookOnePar(buf, os, runparams, 
+			par->simpleDocBookOnePar(buf, os, runparams,
 					text.outerFont(distance(paragraphs.begin(), par)));
 		} else {
 			sgml::openTag(buf, os, runparams, *par);
-			par->simpleDocBookOnePar(buf, os, runparams, 
+			par->simpleDocBookOnePar(buf, os, runparams,
 					text.outerFont(distance(paragraphs.begin(), par)));
 			sgml::closeTag(os, *par);
 		}
@@ -310,7 +312,7 @@ ParagraphList::const_iterator makeCommand(
 	return pend;
 }
 
-} // end anonym namespace
+} // namespace
 
 
 void docbookParagraphs(Text const & text,
