@@ -135,16 +135,13 @@ docstring EndTag::writeEndTag() const
 }
 
 
-docstring ParTag::writeTag() const
+ParTag::ParTag(std::string const & tag, std::string attr,
+       std::string const & parid)
+  : StartTag(tag)
 {
-	docstring output = StartTag::writeTag();
-
-	if (parid_.empty())
-		return output;
-
-	string const pattr = "id='" + parid_ + "'";
-	output += html::CompTag("a", pattr).writeTag();
-	return output;
+	if (!parid.empty())
+		attr += " id='" + parid + "'";
+	attr_ = attr;
 }
 
 
@@ -175,6 +172,7 @@ string fontToTag(html::FontTypes type)
 	case FT_DBAR:
 		return "u";
 	case FT_SOUT:
+	case FT_XOUT:
 		return "del";
 	case FT_ITALIC:
 		return "i";
@@ -214,6 +212,7 @@ string fontToAttribute(html::FontTypes type)
 		return "";
 	case FT_DBAR:
 		return "class='dline'";
+	case FT_XOUT:
 	case FT_SOUT:
 		return "class='strikeout'";
 	case FT_WAVE:
@@ -294,21 +293,27 @@ XHTMLStream::XHTMLStream(odocstream & os)
 
 
 #ifdef XHTML_DEBUG
-void XHTMLStream::dumpTagStack(string const & msg) const
+void XHTMLStream::dumpTagStack(string const & msg)
 {
-	writeError(msg + ": Tag Stack");
-	TagStack::const_reverse_iterator it = tag_stack_.rbegin();
-	TagStack::const_reverse_iterator en = tag_stack_.rend();
+	*this << html::CR();
+	writeError(msg);
+	*this << html::CR();
+	writeError("Tag Stack");
+	TagDeque::const_reverse_iterator it = tag_stack_.rbegin();
+	TagDeque::const_reverse_iterator en = tag_stack_.rend();
 	for (; it != en; ++it) {
-		writeError(it->tag_);
+		writeError(it->get()->tag_);
 	}
+	writeError("End Tag Stack");
+	*this << html::CR();
 	writeError("Pending Tags");
 	it = pending_tags_.rbegin();
 	en = pending_tags_.rend();
 	for (; it != en; ++it) {
-		writeError(it->tag_);
+		writeError(it->get()->tag_);
 	}
-	writeError("End Tag Stack");
+	writeError("End Pending Tags");
+	*this << html::CR();
 }
 #endif
 
@@ -323,7 +328,7 @@ void XHTMLStream::writeError(std::string const & s) const
 namespace {
 	// an illegal tag for internal use
 	static html::StartTag const parsep_tag("&LyX_parsep_tag&");
-}
+} // namespace
 
 
 bool XHTMLStream::closeFontTags()
@@ -332,6 +337,10 @@ bool XHTMLStream::closeFontTags()
 		// we haven't had any content
 		return true;
 
+#ifdef	XHTML_DEBUG
+	dumpTagStack("Beging Close Font Tags");
+#endif
+
 	// this may be a useless check, since we ought at least to have
 	// the parsep_tag. but it can't hurt too much to be careful.
 	if (tag_stack_.empty())
@@ -348,6 +357,10 @@ bool XHTMLStream::closeFontTags()
 		curtag = tag_stack_.back();
 	}
 
+#ifdef	XHTML_DEBUG
+	dumpTagStack("End Close Font Tags");
+#endif
+
 	if (*curtag == parsep_tag)
 		return true;
 
@@ -365,15 +378,18 @@ bool XHTMLStream::closeFontTags()
 }
 
 
-void XHTMLStream::startParagraph(bool keep_empty)
+void XHTMLStream::startDivision(bool keep_empty)
 {
 	pending_tags_.push_back(makeTagPtr(html::StartTag(parsep_tag)));
 	if (keep_empty)
 		clearTagDeque();
+#ifdef	XHTML_DEBUG
+	dumpTagStack("StartDivision");
+#endif
 }
 
 
-void XHTMLStream::endParagraph()
+void XHTMLStream::endDivision()
 {
 	if (isTagPending(parsep_tag)) {
 		// this case is normal. it just means we didn't have content,
@@ -387,11 +403,16 @@ void XHTMLStream::endParagraph()
 			if (*cur_tag == parsep_tag)
 				break;
 		}
+
+#ifdef	XHTML_DEBUG
+		dumpTagStack("EndDivision");
+#endif
+
 		return;
 	}
 
 	if (!isTagOpen(parsep_tag)) {
-		writeError("No paragraph separation tag found in endParagraph().");
+		writeError("No division separation tag found in endDivision().");
 		return;
 	}
 
@@ -405,6 +426,10 @@ void XHTMLStream::endParagraph()
 		writeError("Tag `" + cur_tag->tag_ + "' still open at end of paragraph. Closing.");
 		os_ << cur_tag->writeEndTag();
 	}
+
+#ifdef	XHTML_DEBUG
+	dumpTagStack("EndDivision");
+#endif
 }
 
 
@@ -845,7 +870,7 @@ ParagraphList::const_iterator makeParagraphs(Buffer const & buf,
 		//
 		// But there is also a special case, and we first see whether we are in it.
 		// We do not want to open the paragraph tag if this paragraph contains
-		// only one item, and that item is "inline", i.e., not HTMLIsBlock (such 
+		// only one item, and that item is "inline", i.e., not HTMLIsBlock (such
 		// as a branch). On the other hand, if that single item has a font change
 		// applied to it, then we still do need to open the paragraph.
 		//
@@ -865,7 +890,7 @@ ParagraphList::const_iterator makeParagraphs(Buffer const & buf,
 				special_case = true;
 		}
 
-		bool const opened = runparams.html_make_pars
+		bool const open_par = runparams.html_make_pars
 			&& (!runparams.html_in_par || par != pbegin)
 			&& !special_case;
 
@@ -876,27 +901,27 @@ ParagraphList::const_iterator makeParagraphs(Buffer const & buf,
 		//        but we are in the first par, and there is a next par.
 		ParagraphList::const_iterator nextpar = par;
 		++nextpar;
-		bool const needclose =
-			(opened && (!runparams.html_in_par || nextpar != pend))
-			|| (!opened && runparams.html_in_par && par == pbegin && nextpar != pend);
+		bool const close_par =
+			(open_par && (!runparams.html_in_par || nextpar != pend))
+			|| (!open_par && runparams.html_in_par && par == pbegin && nextpar != pend);
 
-		if (opened) {
-			// We do not issue the paragraph id if we are doing 
+		if (open_par) {
+			// We do not issue the paragraph id if we are doing
 			// this for the TOC (or some similar purpose)
 			openParTag(xs, lay, par->params(),
 			           runparams.for_toc ? "" : par->magicLabel());
 		}
 
-		docstring const deferred = par->simpleLyXHTMLOnePar(buf, xs, 
+		docstring const deferred = par->simpleLyXHTMLOnePar(buf, xs,
 			runparams, text.outerFont(distance(begin, par)),
-			opened, needclose);
+			open_par, close_par);
 
-        if (needclose) {
-            closeTag(xs, lay);
-            xs << html::CR();
-        }
+		if (close_par) {
+			closeTag(xs, lay);
+			xs << html::CR();
+		}
 
-        if (!deferred.empty()) {
+		if (!deferred.empty()) {
 			xs << XHTMLStream::ESCAPE_NONE << deferred << html::CR();
 		}
 	}
@@ -1088,24 +1113,14 @@ void makeCommand(Buffer const & buf,
 		    documentClass().counters().step(style.counter, OutputUpdate);
 
 	bool const make_parid = !runparams.for_toc && runparams.html_make_pars;
-	
-	if (style.labeltype == LABEL_ABOVE)
-		xs << html::StartTag("div")
-		   << pbegin->params().labelString()
-		   << html::EndTag("div");
-	else if (style.labeltype == LABEL_CENTERED)
-		xs << html::StartTag("div", "style = \"text-align: center;\"")
-		   << pbegin->params().labelString()
-		   << html::EndTag("div");
 
 	openParTag(xs, style, pbegin->params(),
 	           make_parid ? pbegin->magicLabel() : "");
 
 	// Label around sectioning number:
 	// FIXME Probably need to account for LABEL_MANUAL
-	if (style.labeltype != LABEL_NO_LABEL &&
-	    style.labeltype != LABEL_ABOVE &&
-	    style.labeltype != LABEL_CENTERED ) {
+	// FIXME Probably also need now to account for labels ABOVE and CENTERED.
+	if (style.labeltype != LABEL_NO_LABEL) {
 		openLabelTag(xs, style);
 		xs << pbegin->params().labelString();
 		closeLabelTag(xs, style);
