@@ -16,6 +16,8 @@
 #include <time.h>
 #include <string>
 
+#include "strfwd.h"
+
 
 namespace lyx {
 namespace support {
@@ -25,9 +27,17 @@ time_t current_time();
 /** Returns a locale-dependent formatting of the date
  *  and time encoded in \c time. The \p fmt string
  *  holds the formatting arguments of \c strftime.
+ *  Prefer the function formatted_datetime below.
  */
 std::string const formatted_time(time_t t, std::string const & fmt);
 
+/** Returns a locale-dependent formatting of the date and time encoded in \c t
+ *  The \p fmt string holds the formatting arguments of QDateTime::toString().
+ *  If fmt is empty then the formatting of the date and time is itself according
+ *  to the locale.
+ */
+docstring formatted_datetime(time_t t, std::string const & fmt = "");
+
 /**
  * Inverse of asctime(gmtime()).
  */
