@@ -12,7 +12,7 @@
 #ifndef LYX_REGEXP_H
 #define LYX_REGEXP_H
 
-#if defined(LYX_USE_CXX11) && defined(LYX_USE_STD_REGEX)
+#ifdef LYX_USE_STD_REGEX
 #  include <regex>
 // <regex> in gcc is unusable in versions less than 4.9.0
 // see https://gcc.gnu.org/bugzilla/show_bug.cgi?id=53631
@@ -37,10 +37,20 @@ namespace regex_constants
 {
 using namespace LR_NS::regex_constants;
 using LR_NS::regex_constants::match_flag_type;
-}
+} // namespace regex_constants
 
-}
+} // namespace lyx
 
 #undef LR_NS
 
+#ifdef LYX_USE_STD_REGEX
+// Match Begin and End of String when using ECMAScript (default std::regex)
+#define REGEX_BOS "^"
+#define REGEX_EOS "$"
+#else
+// Match Begin and End of String when using Perl RE (default boost::regex)
+#define REGEX_BOS "\\`"
+#define REGEX_EOS "\\'"
+#endif
+
 #endif
